(* control.fun - special built-in contro predicates - fail, once, and	*)
(* cut (!).								*)

(* Copyright (c) 1991,1994,1995 by Carnegie Mellon University		*)
(* Copyright (c) 1994,1995 by AT&T Bell Laboratories			*)
(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Authors:								*)
(*	Amy Felty <felty@bell-labs.com>					*)
(*	Elsa Gunter <elsa@research.att.com>				*)
(*	Frank Pfenning <fp@cs.cmu.edu>					*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)


functor Control
    (structure I : INTERPRETER
     structure IU : IU
     structure CompTable : COMP_TABLE

     val control_mod : CompTable.module

     sharing type I.i_record = IU.i_record
     sharing type I.lterm = IU.lterm
     sharing type CompTable.compiled_pred = IU.compiled_pred
     sharing type I.constraint = IU.constraint) =
 struct

local
    open IU;
in
	
    fun unexpected () =
	raise Basic.InternalError "Control: Unexpected form of goal.";

    fun fail _ = ();

    fun once ((_, [g]), record, con, sc) =
	let
	    exception OnceSuccess of constraint
	in
	    I.solve (g, record, con,
		     (fn newcon =>
		      raise (OnceSuccess newcon)))
	    handle OnceSuccess newcon => sc newcon
	end
      | once _ = unexpected ();
	
    fun cut (_, (IR {ctag, ...}), con, sc) =
	(sc con; raise ctag);

    val specials = [("fail", GFunc fail),
		    ("once", GFunc once),
		    ("!", GFunc cut)];
    
    val _ = map (CompTable.make control_mod) specials;

end
end; (* functor Specials *)
