(* exception.fun - lProlog level exception raising and handling.	*)

(* Copyright (c) 1994,1995 by AT&T Bell Laboratories			*)
(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Authors:								*)
(*	Amy Felty <felty@bell-labs.com>					*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)


functor Exception
    (structure Lam : LAM
     structure Interpreter : INTERPRETER
     structure IU : IU
     structure CompTable : COMP_TABLE

     val exn_mod : CompTable.module
     exception exn of Lam.lterm;

     sharing type CompTable.compiled_pred = IU.compiled_pred
     sharing type Interpreter.i_record = IU.i_record
     sharing type Lam.lterm = Interpreter.lterm = IU.lterm
     sharing type  Lam.constraint = IU.constraint = Interpreter.constraint)
	 : EXCEPTION =
struct
local
    open Lam
in
    type lterm = Lam.lterm;
    exception exn = exn;

    fun unexpected () = raise Basic.InternalError "Exception: unexpected args";
	

    fun raise_exception ((_, [g]), _, _, _) =
	raise exn g
      | raise_exception _ = unexpected ();

    fun handle_exception ((_, [f, protected, solution]), record, con, sc) =

	(* Because we need to trail to uninstantiate variables when an
	 * exception is signaled, and we signal failure (here) by raising
	 * an exception and not by returning, the implementation of
	 * handle_exception is a bit messy.  We need to maintain two
	 * pieces of state: one which keeps track of whether or not we
	 * are in the scope of the handler, and another that stores an
	 * error which we may be able to handle. *)
	let
	    val in_handler_scope = ref true
	    val error = ref (NONE : lterm option)
		
	    val sc' =
		fn newcon =>
		(in_handler_scope := false;
		 sc newcon;
		 in_handler_scope := true)
	in
	    Trail.trail
	    (fn () =>
	     (Interpreter.solve (protected, record, con, sc')
	      handle err as (exn M) =>
		  error := SOME M));

	    case (!error, !in_handler_scope) of
		(SOME g, true) => 
		    (Unify.unify g f con 
		     (fn newcon =>
		      Interpreter.solve (solution, record, newcon, sc));
		     raise exn g)

	      | (SOME err, false) => raise exn err
		    
	      (* Otherwise there is no exception *)
	      | _ => ()
	end
      | handle_exception _ = unexpected ();

    
    val preds = [("exception", IU.GFunc raise_exception),
		 ("handle", IU.GFunc handle_exception)];

    val _ = map (CompTable.make exn_mod) preds;

end (* local open Lam *)
end; (* functor Exception *)
