(* file.fun - built-ins for file manipulation.				*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Authors:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)


functor File
    (structure Lam : LAM
     structure Exception : EXCEPTION
     structure Module : MODULE
     structure IU : IU
     structure CompTable : COMP_TABLE

     val file_mod : Module.module

     sharing type Lam.BI.const = IU.bi_const
     sharing type Lam.lterm = IU.lterm = Exception.lterm = CompTable.lterm
     sharing type Lam.const = Module.const
     sharing type CompTable.compiled_pred = IU.compiled_pred
     sharing type Module.module = CompTable.module = IU.module
     sharing type Lam.constraint = IU.constraint) =
struct

local
    open Lam IU;
in

    fun unexpected () = raise Basic.InternalError "File: unexpected args";

    val file_not_found = get_const file_mod "file_not_found";
    val file_unreadable = get_const file_mod "file_unreadable";

    fun open_in ((_, [M1, stream]), _, con, sc) =
	(let
	     val filename =
		 need "string argument to open_in must be rigid."
		 (theString M1)
	 in
	     (Unify.unify
	      (makeBi (BI.make_in_stream (Lib.IO.open_in filename)))
	      stream con sc)
	     handle Lib.IO.Io msg =>

		 (* This is a horrendous hack - It needs to be fixed *)
		 (case Lib.String.substring (msg, (size msg) - 20, 20) of
		      "ch file or directory" => 
			  raise Exception.exn
			      (LTerm.construct_application
			       (file_not_found,
				makeString filename))
		    | "d, Permission denied" => 
			  raise Exception.exn
			      (LTerm.construct_application
			       (file_unreadable,
				makeString filename))
		    | _ => raise Lib.IO.Io msg)
	 end)
      | open_in _ = unexpected ();

    fun open_out ((_, [filename, stream]), _, con, sc) =
	Unify.unify
	(makeBi
	 (BI.make_out_stream
	  (Lib.IO.open_out
	   (need "string argument to open_out must be rigid."
	    (theString filename)))))
	stream con sc
      | open_out _ = unexpected ();
	
    fun open_append ((_, [filename, stream]), _, con, sc) =
	Unify.unify
	(makeBi
	 (BI.make_out_stream
	  (Lib.IO.open_append
	   (need "string argument ot open_append must be rigid"
	    (theString filename)))))
	stream con sc
      | open_append _ = unexpected ();

    fun close_in ((_, [stream]), _, con, sc) =
	(Lib.IO.close_in
	 (need "in_stream argument to close_in must be rigid."
	  (theInStream stream));
	 sc con)
      | close_in _= unexpected ();

    fun close_out ((_, [stream]), _, con, sc) =
	(Lib.IO.close_out
	 (need "out_stream argument to close_out must be rigid."
	  (theOutStream stream));
	 sc con)
      | close_out _ = unexpected ();

    val funcs = [("open_in", GFunc open_in),
		 ("open_out", GFunc open_out),
		 ("open_append", GFunc open_append),
		 ("close_in", GFunc close_in),
		 ("close_out", GFunc close_out)];

    val _ = map (CompTable.make file_mod) funcs;

end (* local *)
end; (* functor File *)
