(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Author:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)


functor Ground
    (structure LTerm : LTERM_SIMPLE
     structure Unify : UNIFY
     structure IU : IU
     structure CompTable : COMP_TABLE
     structure Module : MODULE
     structure LpList : LP_LIST

     val ground_mod : Module.module

     sharing type CompTable.module = IU.module = Module.module
     sharing type Module.const = LTerm.Const.const
     sharing type Module.tp_const = LTerm.Type.Const.const
     sharing type LTerm.Type.tp = LpList.tp
     sharing type LTerm.Type.tp = IU.tp
     sharing type IU.compiled_pred = CompTable.compiled_pred
     sharing type IU.constraint = Unify.constraint
     sharing type Unify.lterm = LTerm.lterm = IU.lterm = LpList.lterm) =
struct

local
    open LTerm
in

    val SOME (Module.Con new) = Module.sign_lookup [ground_mod] "new";
    val SOME (Module.Con var_cnstr) =
	Module.sign_lookup [ground_mod] "var_cnstr";
    val SOME (Module.TypeCon abst_const) =
	Module.sign_lookup [ground_mod] "abst";
    val SOME (Module.TypeCon var_const) =
	Module.sign_lookup [ground_mod] "var";

    val abst = LTerm.Type.construct_const abst_const;
    val var = LTerm.Type.construct_const var_const;

    fun ground (tp, M) =
	let
	    fun find (evar, (evar' :: ls)) =
		if LTerm.equal_head evar evar' then
		    SOME (length ls)
		else
		    find (evar, ls)
	      | find (_, nil) = NONE

	    fun g (App (M, N), i, evars) =
		let
		    val (N', evars') = g (N, i, evars)
		    val (M', evars'') = g (M, i, evars')
		in
		    (App (M', N'), evars'')
		end
	      | g (Lam (binder, M), i, evars) =
		let
		    val (M', evars') = g (M, i + 1, evars)
		in
		    (Lam (binder, M'), evars')
		end
              | g (Evar (_, ref (SOME M)), i, evars) =
		g (M, i, evars)
	      | g (e as Evar (ev, ref NONE), i, evars) =
		(case (find (e, evars)) of
		     NONE =>
			 (Index (i + (length evars)), e :: evars)
		   | SOME j =>
			 (Index (i + j), evars))

	      (* ConstUvar *)
	      | g (M, i, evars) = (M, evars)

	    val (M', evars) = g (M, 1, nil)

	    val make_type =
		fn evar_tp =>
		Type.construct_arrow
		(Type.construct_arrow (evar_tp, tp),
		 Type.construct_application (abst, tp))

	    val M'' =
		Lib.List.foldr
		(fn (evar, M) =>
		 let
		     val evar_tp = type_of evar
		     val new =
			 construct_const (new, make_type evar_tp)
		 in
		     App (new, Lam ((evar_tp, name_hint evar), M))
		 end)
		M'
		evars

	    val list_var =
		Lib.List.foldr
		(fn (evar, ls) =>
		 LpList.lp_cons
		 (var,
		  App (ConstUvar
		       (var_cnstr,
			Type.construct_arrow (type_of evar, var)),
		       evar),
		  ls))
		(LpList.lp_nil var)
		evars
	in
	    (list_var, M'')
	end;

    fun unexpected () = raise Basic.InternalError "Ground: unexpected args";

    fun ground_pred ((tp, [L, M, N]), _, con, sc) =
	let
	    val SOME (tp', _) = Type.destruct_arrow tp
	    val (list_var, L') = ground (tp', L)
	in
	    Unify.unify L' M con
	    (fn con' =>
	     Unify.unify list_var N con' sc)
	end
      | ground_pred _ = unexpected ();

    val _ = CompTable.make ground_mod ("ground", IU.GFunc ground_pred);

end (* local open LTerm *)
end; (* functor Ground *)
