(* stream_io.fun - built-in stream io predicates.			*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Author:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)


functor StreamIo
    (structure Lam : LAM
     structure Error : ERROR
     structure CompTable : COMP_TABLE
     structure Module : MODULE
     structure IU : IU

     val stream_io_mod : Module.module
     
     sharing type IU.lterm = Lam.lterm = CompTable.lterm
     sharing type IU.compiled_pred = CompTable.compiled_pred
     sharing type IU.bi_const = Lam.BI.const
     sharing type IU.constraint = Lam.constraint
     sharing type CompTable.module = Module.module
     sharing type Module.const = Lam.const) =
struct

local
    open Lam IU;
in

    fun unexpected () =
	raise Basic.InternalError "StreamIO: Unexpected for of goal.";

    val _ =
	app
	(Module.sign_insert stream_io_mod)
	[("std_in",
	  Module.Con
	  (Const.construct_bi_const (BI.make_in_stream Lib.IO.std_in))),
	 ("std_out",
	  Module.Con
	  (Const.construct_bi_const (BI.make_out_stream Lib.IO.std_out))),
	 ("std_err",
	  Module.Con
	  (Const.construct_bi_const (BI.make_out_stream Lib.IO.std_err)))];

    fun open_string ((_, [string, stream]), _, con, sc) =
	Unify.unify
	(makeBi
	 (BI.make_in_stream
	  (Lib.IO.open_string
	   (need "string argument to open_string must be rigid."
	    (theString string)))))
	stream con sc
      | open_string _ = unexpected ();

    fun output ((_, [M1, M2]), _, con, sc) =
	(Lib.IO.output
	 (need "out_stream argument to output must be rigid."(theOutStream M1),
	  need "string argument to output must be rigid." (theString M2));
	 sc con)
      | output _ = unexpected ();

    fun input ((_, [M1, M2, M3]), _, con, sc) =
	Unify.unify
	(makeString
	 (Lib.IO.input
	  (need "in_stream argument to input must be rigid." (theInStream M1),
	   need "int argument to inpout must be rigid." (theInt M2))))
	M3 con sc
      | input _ = unexpected ();

    fun input_line ((_, [M1, M2]), _, con, sc) =
	Unify.unify
	(makeString
	 (Lib.IO.input_line
	  (need "in_stream argument to input_line must be rigid."
	   (theInStream M1))))
	M2 con sc
      | input_line _ = unexpected ();

    fun lookahead ((_, [M1, M2]), _, con, sc) =
	Unify.unify
	(makeString
	 (Lib.IO.lookahead
	  (need "in_stream argument to lookahead must be rigid."
	   (theInStream M1))))
	M2 con sc
      | lookahead _ = unexpected ();

    fun eof ((_, [M]), _, con, sc) =
	if Lib.IO.end_of_stream
	    (need "in_stream argument to eof must be rigid."
	     (theInStream M))
	    then sc con else ()
      | eof _ = unexpected ();

    fun flush ((_, [M]), _, con, sc) =
	(Lib.IO.flush_out
	 (need "out_stream argument to flush must be rigid." (theOutStream M));
	 sc con)
      | flush _ = unexpected ();

    val funcs =  [("open_string", GFunc open_string),
		  ("output", GFunc output),
		  ("input", GFunc input),
		  ("input_line", GFunc input_line),
		  ("lookahead", GFunc lookahead),
		  ("eof", GFunc eof),
		  ("flush", GFunc flush)];

    val _ = map (CompTable.make stream_io_mod) funcs;
	
end
end; (* functor StreamIo *)
