
(* Copyright (c) 1991,1994,1995 by Carnegie Mellon University		*)
(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Authors:								*)
(*	Frank Pfenning <fp@cs.cmu.edu>					*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)


signature ABSYN =
    sig

	include FIXITY;

	type tp;
	type kind;
	type tp_const;
	type const;

	datatype sign_entry =
	    TypeCon of tp_const
	  | Con of const;

	type id;

	type location;
	    
	(* generic lambda terms (sterm stands for simple term) - absyn builds
	 * sterms which are converted to the lambda terms used by the rest of
	 * the code by the LTerm structure. *)
	datatype sterm =
	    Lam of (tp * string option) * sterm
	  | App of sterm * sterm
	  | Index of int
	  | Const of const * tp
	  | Fvar of tp * string
	  | Mark of location * sterm
	  | HasType of sterm * tp;

	type aatom;			(* abstract atom *)
	type aterm;			(* abstract term *)
	type atermseq;			(* abstract term sequence *)

	type atypeatom;			(* abstract type atom *)
	type atype;			(* abstract type *)
	type atypeseq;			(* abstract type sequence *)

	type akind;			(* abstract kind *)

	val to_term : (string -> sign_entry option) -> aterm ->
	    (tp * string) list * (tp * string) list * sterm;
	val to_type : (string -> sign_entry option) -> atype -> tp;
	val to_kind : akind -> kind;

	val mk_oneseq : aatom -> location -> atermseq
	val mk_termseq : atermseq * aatom -> location -> atermseq
	val seq_to_term : atermseq -> location -> aterm

	(* make lower-case identifier *)
	val mk_lcid		: string -> location -> id;
	(* make upper-case identifier *)
	val mk_ucid		: string -> location -> id;
	(* make type annotated identifier *)
	val mk_of_type		: (id * atype) -> location -> id;

	(* make an abstraction *)
	val mk_abst		: id * aterm -> location -> aterm
	(* make type annotated term *)
	val mk_hastype		: aterm * atype -> location -> aterm
	(* make an unnamed free variable (_) *)
	val mk_wildcard		: location -> aterm;

	(* make a bound variable or free variable *)
	val mk_bv_fv		: string -> location -> aatom;
	(* make a bound variable or constant *)
	val mk_bv_const		: string -> location -> aatom;
	(* make a constant *)
	val mk_const		: string -> location -> aatom

	val atom_to_term	: aatom -> aterm
	val term_to_atom	: aterm -> aatom
	val id_to_atom		: id -> location -> aatom;

	(* Build-ins *)
	val mk_string		: string -> location -> aterm;
	val mk_int		: int -> location -> aterm;
	val mk_real		: real -> location -> aterm;

	(* Types *)
	val mk_arrow		: atype * atype -> location -> atype
	val mk_tapp		: atype * atype -> location -> atype
	val mk_ftv		: string -> location -> atype;
	val mk_tconst		: string -> location -> atype;

	val seq_to_type		: atypeseq -> location -> atype;
	val type_to_atom	: atype -> atypeatom;
	val mk_onetypeseq	: atypeatom -> location -> atypeseq;
	val mk_typeseq		: (atypeseq * atypeatom) -> location ->
					atypeseq;


        (* Built-in types *)
	val mk_string_type	: location -> atype;
	val mk_int_type		: location -> atype;
	val mk_real_type	: location -> atype;
	val mk_in_stream_type	: location -> atype;
	val mk_out_stream_type	: location -> atype;
	    
	(* Kinds *)
	val mk_type		: location -> akind;
	val mk_karrow		: akind -> location -> akind;

    end; (* signature ABSYN *)
