(* bi_const.fun - built-in constants					*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Author:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)


functor TypeBuiltIns
    (structure Kind : KIND)
	 : TYPE_BUILT_INS =
struct
    structure Kind = Kind;

    type tp = Kind.kind;

    datatype internal_const =
	IntType
      | RealType
      | StringType
      | InStreamType
      | OutStreamType;
    type const = internal_const;

    val equal = Lib.Misc.equal;

    fun type_of _ = Kind.Type;

    fun makestring_const IntType = "int"
      | makestring_const RealType = "real"
      | makestring_const StringType = "string"
      | makestring_const InStreamType = "in_stream"
      | makestring_const OutStreamType = "out_stream";
end; (* functor TypeBuiltIns *)

functor BuiltIns
    (structure TypeBuiltIns : TYPE_BUILT_INS
     structure Type : TYPE

     sharing type Type.Const.bi_const = TypeBuiltIns.const)
	 : BUILT_INS =
struct

    structure TypeBuiltIns = TypeBuiltIns;

    datatype internal_const =
	Int of int
      | Real of real
      | String of string
      (* The ints in InStream and OutStream are included for equality checks *)
      | InStream of Lib.IO.instream * int
      | OutStream of Lib.IO.outstream * int;
    type const = internal_const;

    type tp = Type.tp;

    fun equal (Int i) (Int j) = i = j
      | equal (Real r) (Real s) = Real.== (r, s)
      | equal (String s) (String t) = s = t
      | equal (InStream (_, s1)) (InStream (_, s2)) = s1 = s2
      | equal (OutStream (_, s1)) (OutStream (_, s2)) = s1 = s2
      | equal _ _ = false;

    val make_tp = Type.construct_const o Type.Const.construct_bi_const;

    fun type_of (Int _) = make_tp TypeBuiltIns.IntType
      | type_of (Real _) = make_tp TypeBuiltIns.RealType
      | type_of (String _) = make_tp TypeBuiltIns.StringType
      | type_of (InStream _) = make_tp TypeBuiltIns.InStreamType
      | type_of (OutStream _) = make_tp TypeBuiltIns.OutStreamType;

    fun makestring_const (Int i) = Lib.Convert.itoa i
      | makestring_const (Real r) = Lib.Convert.ftoa r
      | makestring_const (String s) = "\"" ^ s ^ "\""
      (* InStream and OutStream *)
      | makestring_const _ = "-";

local
    val counter = ref 0;
in
    fun make_in_stream stream = InStream (stream, Lib.Misc.pre_inc counter);
    fun make_out_stream stream = OutStream (stream, Lib.Misc.pre_inc counter);
end;

end; (* functor BuiltIns *)
