(* bi_const.sig - built-in constants					*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Author:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)


signature BI_CONST =
sig

    type const;
    type tp;

    val equal : const -> const -> bool;
    val type_of : const -> tp;
    val makestring_const : const -> string;

end; (* signature BI_CONST *)

signature TYPE_BUILT_INS =
    sig
	include BI_CONST;
	
	structure Kind : KIND
	sharing type tp = Kind.kind;

        datatype internal_const =
	    IntType
	  | RealType
	  | StringType
	  | InStreamType
	  | OutStreamType
	sharing type internal_const = const;
    end; (* TYPE_BUILT_INS *)

signature BUILT_INS =
    sig
	include BI_CONST;
	
	structure TypeBuiltIns : TYPE_BUILT_INS
		
	datatype internal_const =
	    Int of int
	  | Real of real
	  | String of string
	  (* The ints in InStream and
	   OutStream are included for equality checks *)
	  | InStream of Lib.IO.instream * int
	  | OutStream of Lib.IO.outstream * int
	sharing type internal_const = const;

	val make_in_stream : Lib.IO.instream -> const;
	val make_out_stream : Lib.IO.outstream -> const;

end; (* signature BI_CONST *)
