(* const.sig - constants and operations on them.			*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Author:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)


signature CONST =
sig

    include FIXITY;

    type const;
    type tp;

    (* Operations on constants *)
    val hash_const : const -> int;
    val equal : const -> const -> bool;
    val makestring_const : const -> string;
    val type_of : const -> tp;
    val fixity : const -> fixity;
    val update_fixity : fixity -> const -> unit;

    (* Identify two constants *)
    val merge_consts : const * const -> unit;

    (* create a new constant *)
    val make_const : tp * string -> const;

    (* Built-in constants *)
    type bi_const;
    val construct_bi_const : bi_const -> const;
    val destruct_bi_const : const -> bi_const option;
    val is_bi : const -> bool;

    (* lambda-Prolog constants specific *)
    val age_of : const -> int;
    val make_local : const -> unit;
    val reset_base_time : unit -> unit;
    val new_uvar : tp * string option -> const;
    val is_uvar : const -> bool;
    val name_hint : const -> string option;
    val stamp : unit -> int;

end; (* signature CONST *)
