(* constraints.sig - constraints of unresolved flex-flex pairs.		*)

(* Copyright (c) 1991,1994,1995 by Carnegie Mellon University		*)
(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Authors:								*)
(*	Frank Pfenning <fp@cs.cmu.edu>					*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

signature CONSTRAINTS =
sig

    type lterm;
    type tp;
    type constraint;

    val empty_constraint : constraint;
    val is_empty_constraint : constraint -> bool;

end  (* signature CONSTRAINTS *)


signature CONSTRAINTS_TYPES =
sig

    include CONSTRAINTS;

    datatype anno_lterm =
	Rigid of lterm * (lterm * lterm list)	(* (term, (head, args)) *)
      | Gvar of lterm * (lterm * lterm list)	(* (term, (head, args)) *)
      | Flex of lterm * lterm			(* (term, head)  *)
      | Abstraction of
	(tp * string option) * lterm		(* (binder, body) *)
      | Any of lterm;				(* term *)

    datatype dpair = DPair of anno_lterm * anno_lterm;
    datatype internal_constraint = Con of dpair list
    sharing type internal_constraint = constraint;

    val annotate : lterm -> anno_lterm;
    val reannotate_dset : dpair list -> dpair list;
    val bare_term : anno_lterm -> lterm;

end; (* signature CONSTRAINTS_TYPES *)
