(* lam.sml - the lam structure						*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Author:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

signature LAM =
    sig
	structure Type : TYPE;

	structure BI : BUILT_INS;

	structure Const : CONST;

	structure Absyn : ABSYN;

	structure LTerm : LTERM
	sharing LTerm.Type = Type;

	structure Reduce : REDUCE;

	structure Constraints : CONSTRAINTS;
    
	structure Trail : TRAIL;

	structure Unify : UNIFY;

	structure Simplify : SIMPLIFY;

	structure Print : PRINT;

	structure TypeRecon : TYPE_RECON;

	type tp
	sharing type tp = Type.tp = TypeRecon.tp = Absyn.tp = Const.tp =
	    Print.tp = Reduce.tp = BI.tp;

	type kind
	sharing type kind = Type.Kind.kind = Absyn.kind;

	type sterm
	sharing type sterm = TypeRecon.sterm  = Absyn.sterm = LTerm.sterm;

	type lterm
	sharing type lterm = LTerm.lterm = Print.lterm = Unify.lterm =
	    Reduce.lterm;
	    
        type const
	sharing type const = Const.const = LTerm.Const.const = Absyn.const;

	type tp_const
	sharing type Type.Const.const = Absyn.tp_const;

	type fixity
	sharing type fixity = Type.Const.fixity = Const.fixity = Absyn.fixity;

        type constraint
	sharing type constraint = Constraints.constraint = Unify.constraint =
	    Simplify.constraint = Print.constraint;

	sharing type Const.bi_const = BI.const;
    end; (* signature LAM *)
    

structure Lam : LAM =
    struct

	type sterm = Absyn.sterm;
	type tp = Type.tp;
	type kind = Type.Kind.kind;
	type lterm = LTerm.lterm;
	type const = Const.const;
	type tp_const = Type.Const.const;
	type fixity = Fixity.fixity;
	type constraint = Constraints.constraint;

	structure Type = Type;
	structure TypeRecon = TypeRecon;

	structure BI = BI;

	structure Const = Const;

	structure Absyn = Absyn;

	structure LTerm = LTerm;

	structure Reduce = Reduce;

	structure Constraints = Constraints;
    
	structure Trail = Trail;

	structure UUtils = UUtils;

	structure Simplify = Simplify;

	structure Unify = Unify;

	structure Print = Print;
    end; (* structure Lam *)
