(* link-sml.sml - lam directory link file for the basic lambda-terms in	*)
(* src/lam/lterm_simple.						*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Author:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

structure Formatter =
    Formatter ();

structure Kind : KIND =
    Kind (structure Formatter = Formatter);

structure TypeBI : TYPE_BUILT_INS =
    TypeBuiltIns (structure Kind = Kind);

structure TConst : CONST =
    Const (structure Fixity = Fixity
	   structure BI = TypeBI);

structure TVar : VAR =
    Var (structure Const = TConst
	 type tp = Kind.kind);

structure PTerm : PTERM =
    PTerm (structure Fixity = Fixity);

structure Trail = Trail ();

structure Type : TYPE =
    Type (structure PTerm = PTerm
	  structure Trail = Trail
	  structure Const = TConst
	  structure Var = TVar
	  structure Kind = Kind
	  structure BI = TypeBI
	  structure Fixity = Fixity);


structure BI : BUILT_INS =
    BuiltIns (structure Type = Type
	      structure TypeBuiltIns = TypeBI);

structure Const : CONST =
    Const (structure BI = BI
	   structure Fixity = Fixity);

structure Evar : VAR =
    Var (structure Const = Const
	 type tp = Type.tp);

structure LexerInterface : LEXER_INTERFACE =
    LexerInterface ();

structure Error : ERROR =
    Error (structure Location = LexerInterface);

structure Switch : SWITCH =
    Switch (structure Error = Error
	    structure Formatter = Formatter);

structure Absyn =
    Absyn (structure Const = Const
	   structure Fixity = Fixity
	   structure Error = Error
	   structure Type = Type
	   structure BI = BI);

structure LTerm : LTERM_SIMPLE =
    LTermSimple (structure Const = Const
		 structure Evar = Evar
		 structure PTerm = PTerm
		 structure Absyn = Absyn
		 structure Trail = Trail
		 structure Type = Type);

structure Debug =
    Debug (structure LTerm = LTerm);

structure Subst =
    Subst (structure LTerm = LTerm);

structure Reduce =
    Reduce (structure LTerm = LTerm
	    structure Subst = Subst);

structure Constraints =
    Constraints (structure LTerm = LTerm
		 structure Reduce = Reduce);


structure NameEnv : NAME_ENV =
    NameEnv (structure LTerm = LTerm
	     structure Const = Const
	     structure TVar = TVar);

structure Unparse : UNPARSE =
    Unparse (structure Formatter = Formatter
	     structure Fixity = Fixity
	     structure PTerm = PTerm
	     val max_prec = 9);

structure Print : PRINT =
    PrintTerm (structure LTerm = LTerm
	       structure Reduce = Reduce
	       structure PTerm = PTerm

	       (* psw remove *)
	       structure Debug = Debug

	       structure Formatter = Formatter
	       structure Switch = Switch
	       structure Constraints = Constraints
	       structure Name = NameEnv
	       structure Unparse = Unparse);

structure UUtils =
    UUtils (structure LTerm = LTerm
	    structure Reduce = Reduce
	    structure Constraints = Constraints);

structure UnifyLlambda : SIMPLIFY =
    UnifyLlambda (structure LTerm = LTerm

		  (*psw remove *)
		  structure Debug = Debug

		  structure Constraints = Constraints
		  structure Reduce = Reduce
		  structure UU = UUtils);

structure Simplify : SIMPLIFY =
    SimplifyEquals (structure Constraints = Constraints
		    structure Reduce = Reduce);

structure Unify : UNIFY =
    Unify (structure LTerm = LTerm
	   structure Constraints = Constraints
	   structure Print = Print
	   structure UU = UUtils
	   structure Trail = Trail
	   structure Simplify = UnifyLlambda);


structure TypeRecon : TYPE_RECON =
    TypeRecon (structure Type = Type
	       structure Print = Print
	       structure Location = LexerInterface
	       structure LTerm = LTerm
	       structure Const = Const
	       structure Absyn = Absyn);

