(* lterm.sig - signature of abstract lambda-terms			*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Author:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)


signature LTERM =
sig

    structure Type : TYPE;
    structure Const : CONST;

    (* The type of lambda-terms *)
    type lterm;

    val equal_head : lterm -> lterm -> bool;
    (* Equality of logic variables (evars), constants, eigen
     * variables (uvars), and bound variables. It is an error
     * to use this function on anything else.			*)

    (* Functions for creating lambda-terms *)

    val new_uvar : Type.tp * string option -> lterm;
    val new_evar : Type.tp * string option * Const.const list -> lterm;
    (* new_evar (tp, name_op)
     *		Creates a new logic variable with type tp and
     *		optional name hint name_op.		         *)
	
    val make_evar : Type.tp * int * string option * Const.const list -> lterm;
    val make_evar_as : Type.tp * lterm -> lterm;
    (* make_evar (tp, evar)
     *		Creates an evar with name hint name_hint, age, and uvars of
     *		evar and with type tp.	         *)
	    
    val make_bvar : int -> lterm;
     (* make_bvar i
      *		Creates a bound constant which is bound by the
      *		ith surrounding abstraction.			 *)

    val construct_application : lterm * lterm -> lterm;
    val construct_abstraction : (Type.tp * string option) * lterm -> lterm;
    val destruct_abstraction : lterm -> 
	((Type.tp * string option) * lterm) option;

    val construct_const : Const.const * Type.tp -> lterm;
    val destruct_const : lterm -> (Const.const * Type.tp) option;

    val legal_binding : lterm * lterm -> bool;

    val older : lterm * lterm -> bool;
    (* older (evar1, evar2)
     *		true if the time stamp of evar1 is lower than
     *		the time stamp of evar2, i.e., t2 is quantified
     *		in the scope of	t1. It is an error to call this
     *		function on anything other than evars.		 *)

    val bind_evar : lterm * lterm -> unit;
    val unbind_evar : lterm -> unit;

    (* instantiate evar preforms trailng, while bind evar does not. *)
    val instantiate_evar : lterm * lterm -> unit;

    (* Only works for constants, evars, and uvars. *)
    val type_of : lterm -> Type.tp;

    (* Conversions *)

    (* sterm stands for simple term - Absyn parses into sterms *)
    type sterm;
    val sterm_to_lterm : sterm -> lterm;

    val name_hint : lterm -> string option;
    val age_of : lterm -> int;

    (* This is a bad hack - refresh_types preforms a renaming of all type
     * variables in the types of the components of the given term. It is
     * used by the interpreter. *)
    val refresh_types : Type.env -> lterm -> lterm;
	
end; (* signature LTERM *)
