(* constraints.fun - constraints					*)

(* Copyright (c) 1991,1994,1995 by Carnegie Mellon University		*)
(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Authors:								*)
(*	Frank Pfenning <fp@cs.cmu.edu>					*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

functor Constraints
    (structure LTerm : LTERM_SIMPLE
     structure Reduce : REDUCE

     sharing type LTerm.lterm = Reduce.lterm)
	 : CONSTRAINTS_TYPES =
struct

local
    open LTerm;
in
    type lterm = LTerm.lterm;
    type tp = LTerm.Type.tp;

    datatype anno_lterm =
	Rigid of lterm * (lterm * lterm list)
      | Gvar of lterm * (lterm * lterm list)
      | Flex of lterm * lterm
      | Abstraction of (tp * string option) * lterm
      | Any of lterm;

    datatype dpair = DPair of anno_lterm * anno_lterm;
    datatype internal_constraint = Con of dpair list;
    type constraint = internal_constraint;

    val empty_constraint = Con nil;
    fun is_empty_constraint (Con ls) = null ls;

    fun dominates_all (evar, (const as (ConstUvar _)) :: args) =
	let
	    fun eq_uvar_or_non_uvar (c as ConstUvar _) =
		equal_head c const
	      | eq_uvar_or_non_uvar (Evar (_, ref (SOME M))) =
		eq_uvar_or_non_uvar M
	      | eq_uvar_or_non_uvar _ = true
	in	  
	    (not ((LTerm.legal_binding (evar, const)) orelse
		  (Lib.List.exists eq_uvar_or_non_uvar args))) andalso
	    dominates_all (evar, args)
	end
      | dominates_all (_, nil) = true
      | dominates_all _ = false;
      
    fun anno_norm (M as (Lam (binder, _))) = Abstraction (binder, M)
      | anno_norm (Evar (_, ref (SOME M))) = anno_norm M
      | anno_norm M =
	let
	    fun anorm (head as ConstUvar _) args = Rigid (M, (head, args))
	      | anorm (Evar (_, ref (SOME M))) args = anorm M args
	      | anorm (head as Evar _) args =
		if dominates_all (head, args) then
		    Gvar (M, (head, args))
		else
		    Flex (M, head)
	      | anorm (App (M, N)) args = anorm M (N :: args)

	      (* The following case should not be possible, because if M is
	       * head normal, there should be no abstractions on the left of
	       * App's. *)
	      | anorm _ _ =
		raise Basic.InternalError "anorm: not normalized"
	in
	    anorm M nil
	end;
	
    fun annotate M = anno_norm (Reduce.head_normalize M)

    fun reannotate (M as Rigid _) = M
      | reannotate (M as Flex (_, Evar (_, ref NONE))) = M
      | reannotate (M as Abstraction _) = M
      | reannotate (M as Gvar (_, (Evar (_, ref NONE), _))) = M
      | reannotate (M as Any _) = M
      | reannotate (Flex (M, _)) = annotate M
      | reannotate (Gvar (M, _)) = annotate M;

    fun reannotate_dset (DPair (M, N) :: dset) =
	DPair (reannotate M, reannotate N) :: reannotate_dset dset
      | reannotate_dset nil = nil;

    fun bare_term (Rigid (M, _)) = M
      | bare_term (Flex (M, _)) = M
      | bare_term (Abstraction (_, M)) = M
      | bare_term (Gvar (M, _)) = M
      | bare_term (Any M) = M;


end (* local *)	
end; (* functor Constraints *)
