(* lterm_simple.sig - basic lambda-terms				*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Author:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

signature LTERM_SIMPLE =
sig

    include LTERM;

    structure Evar : VAR
    sharing type Evar.tp = Type.tp = Const.tp
    sharing type Evar.uvar = Const.const;

    datatype internal_lterm =

      (* Abstraction - tp holds type of bound variable *)
	Lam of (Type.tp * string option) * internal_lterm

      (* Application *)
      | App of internal_lterm * internal_lterm

      (* Bound variable *)
      | Index of int

      (* Constants and variables introducted by universal quantification
       (also called Uvars) *)
      | ConstUvar of Const.const * Type.tp

      (* Logic variable (Existential variable) *)
      | Evar of Evar.var * internal_lterm option ref;

    sharing type lterm = internal_lterm;

    (* pterm stands for print term - the unparser unparses pterms *)
    type ('a, 'b) pterm;
    val lterm_to_pterm : lterm -> (Const.const, lterm) pterm;

end; (* signature LTERM_SIMPLE *)
