(* reduce.fun - normalization of lambda-terms				*)

(* Copyright (c) 1991,1994,1995 by Carnegie Mellon University		*)
(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Authors:								*)
(*	Frank Pfenning <fp@cs.cmu.edu>					*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

functor Reduce
    (structure LTerm : LTERM_SIMPLE
     structure Subst : SUBST

     sharing type LTerm.lterm = Subst.lterm)
	 : REDUCE =
struct

    type lterm = LTerm.lterm;
    type tp = LTerm.Type.tp;	

local
    open LTerm;

    exception IsNorm;
in

    fun head_norm (Evar (_, ref (SOME M))) = head_norm M
      | head_norm M = (hnorm M) handle IsNorm => M
    and hnorm (Index _) = raise IsNorm
      | hnorm (Evar (_, ref NONE)) = raise IsNorm
      | hnorm (Evar (_, ref (SOME M))) = head_norm M
      | hnorm (ConstUvar _) = raise IsNorm
      | hnorm (App (M, N)) =
	(case (hnorm M) of
	     M' as (Lam _) => head_norm (Subst.subst (M', N))
	   | M' => App (M', N))
      | hnorm (Lam (tp, M)) = Lam (tp, head_norm M)

    val head_normalize = head_norm;
	
    fun beta_norm (M as (Index _)) = M
      | beta_norm (Evar (_, ref (SOME M))) = beta_norm M
      | beta_norm (M as (Evar _)) = M
      | beta_norm (M as ConstUvar _) = M
      | beta_norm (App (M, N)) =
	let
	    val normal_M = beta_norm M
	in
	    (case normal_M of
		 Lam _  =>
		     beta_norm (Subst.subst (normal_M, N))
	       | _ =>
		     App (normal_M, beta_norm N))
	end
      | beta_norm (Lam (tp, M)) =
	Lam (tp, beta_norm M);

    val beta_normalize = beta_norm;

    fun term_head (App (M, _)) = term_head M
      | term_head (Lam (_, M)) = term_head M
      | term_head (Evar (_, ref (SOME M))) = term_head M
      (* Index _, Evar (_, ref NONE), ConstUvar _ *)
      | term_head M = M

    fun head_args M =
	let
	    fun ha (App (M, N)) args = ha M (N :: args)
	      | ha (Lam (_, M)) args = ha M args
	      | ha (Evar (_, ref (SOME M))) args = ha M args
	      (* Index _, Evar (_, ref NONE), ConstUvar _ *)
	      | ha M args = ((M, type_of M), args)
	in
	     ha M []
	end;
		
    (* This is beta-equality, but it is not as effient as it might be -
     * we should only head_normalize at each step.		     *)
    fun equal_term M N =
	let
	    fun term_eq (Evar (_, ref (SOME M)), N) = term_eq (M, N)
	      | term_eq (M, Evar (_, ref (SOME N))) = term_eq (M, N)

	      | term_eq (Lam (_, M), Lam (_, N)) =
		term_eq (M, N)

	      | term_eq (App (M1, N1), App (M2, N2)) =
		term_eq (M1, M2) andalso term_eq (N1, N2)

	      | term_eq (Index i, Index j) = i = j

	      | term_eq (e1 as Evar _, e2 as Evar _) =
		equal_head e1 e2

	      | term_eq (c1 as ConstUvar _, c2 as ConstUvar _) =
		equal_head c1 c2

	      | term_eq _ = false;
	in
	    term_eq (head_normalize M, head_normalize N)
	end;

end (* local *)
end; (* functor Reduce *)
