(* subst.fun - substitution on simple lambda terms			*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Author:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

functor Subst (structure LTerm : LTERM_SIMPLE) : SUBST =
struct

    type lterm = LTerm.lterm;

local
    open LTerm;
in
    
    fun subst (Lam (_, t), s) =
	let
	    fun deepen (amount, depth) (Lam (tp, term)) =
		Lam (tp, deepen (amount, depth + 1) term)
	      | deepen a_d (App (t1, t2)) =
		App (deepen a_d t1, deepen a_d t2)

	      | deepen (a, d) (Index i) =
		if i > d then
		    Index (i + a)
		else
		    Index i
		    
	      (* Const, Evar, Uvar *)
	      | deepen _ t = t
		
	    fun do_subst (depth, Index i) =
		if i = depth then
		    deepen (depth - 1, 0) s
		else if depth < i then
		    Index (i - 1)
		     else
			 Index i
			 
	      | do_subst (d, Lam (tp, t))=
		Lam (tp, do_subst (d + 1, t))
		
	      | do_subst (d, App (t1, t2)) =
		App (do_subst (d, t1), do_subst (d, t2))
		
	      (* This case holds for Const, Evar, and Uvar. *)
	      | do_subst (_, t) =
		t
	in
	    do_subst (1, t)
	end
      | subst _ =
	raise Basic.InternalError
	    ("first argument to subst is not an abstraction!")
	
end (* local *)
end; (* functor Subst *)
