(* name.fun - utilities to create and associate unique names for	*)
(* terms.								*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Author:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

functor NameEnv
    (structure LTerm : LTERM_SIMPLE
     structure TVar : VAR)
	 : NAME_ENV =
struct

    type evar = LTerm.lterm;
    type uvar = LTerm.Const.const;
    type tvar = TVar.var;

    datatype var =
	T of TVar.var
      | E of LTerm.lterm
      | U of LTerm.Const.const;

    fun equal (T v1) (T v2) =
	TVar.equal v1 v2

      | equal (E (LTerm.Evar (v1, ref (SOME M)))) (N as E(LTerm.Evar (v2, _)))=
	(LTerm.Evar.equal v1 v2) orelse
	(equal (E M) N)

      | equal (E (LTerm.Evar (v1, _))) (E (LTerm.Evar (v2, _))) =
	LTerm.Evar.equal v1 v2
      | equal (U v1) (U v2) =
	LTerm.Const.equal v1 v2
      | equal _ _ = false;

    type name_env = (string * var) list ref * (string -> bool);

    fun make_env func = ((ref nil, func) : name_env);

    fun find_name ((ref ls, func), gen_name) =
	let
	    val new_name = ref (gen_name ())
	in
	    ((while func (! new_name) orelse
		    Lib.List.exists (fn (name', _) => name' = !new_name) ls do
		    (new_name := gen_name ()));
	     ! new_name)
	end;

    fun lookup_by_var (ref ls, _) var =
	let
	    fun lbv ((name, var') :: ls) =
		if equal var' var then (SOME name) else lbv ls
	      | lbv _ = NONE
	in
	    lbv ls
	end;

    fun lookup_by_name (ref ls, _) name =
	let
	    fun lbn ((name', var) :: ls) =
		if name' = name then (SOME var) else lbn ls
	      | lbn _ = NONE
	in
	    lbn ls
	end;
	
    fun add_or_lookup (env as (ls, _)) (var, gen_name) =
	(case (lookup_by_var env var) of
	     SOME name => name
	   | NONE =>
		 let
		     val name = find_name (env, gen_name)
		 in
		     (ls := (name, var) :: (! ls);
		      name)
		 end);

end; (* functor NameEnv *)
