(* simplify_equals.fun - Simplifies constraints by eliminating equal	*)
(* terms.								*)

(* Copyright (c) 1991,1994,1995 by Carnegie Mellon University		*)
(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Authors:								*)
(*	Frank Pfenning <fp@cs.cmu.edu>					*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

functor SimplifyEquals
    (structure Constraints : CONSTRAINTS_TYPES
     structure Reduce : REDUCE

     sharing type Constraints.lterm = Reduce.lterm)
	 : SIMPLIFY =
struct

    type constraint = Constraints.constraint;
    exception NonUnifiable;
    
local
    open Constraints;
in

    fun simplify_constraint  (Con dset) =
	let
	    fun simplify_dpair (DPair (eqM, eqN)) =
		let
		    val M = bare_term eqM
		    and N = bare_term eqN
		in
		    if Reduce.equal_term M N then
			NONE
		    else
			let
			    val eqM' = annotate M
			    val eqN' = annotate N
			in
			    SOME (DPair (eqM', eqN'))
			end
		end
	in 
	    Con (Lib.List.filter simplify_dpair dset)
	end

end  (* local ... *)
end  (* functor SimplifyEquals *)
