(* type.sig - types							*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Author:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

signature TYPE =
sig

    structure Const : CONST;
    structure Var : VAR;
    structure Kind : KIND
    sharing type Kind.kind = Const.tp;

    type tp;

    val new_var : string option -> tp;
    val result_is_flex : tp -> bool;
    val construct_application : tp * tp -> tp;
    val construct_arrow : tp * tp -> tp;
    val destruct_arrow : tp -> (tp * tp) option;
    val construct_const : Const.const -> tp;
    val destruct_const : tp -> Const.const option;

    val constructors : tp -> (Const.const * bool) list;

    datatype env = E of (tp * tp) list ref;
    val make_env : unit -> env;
    val copy_type : env -> tp -> tp;
    val duplicate_type : tp -> tp;

    (* equality upto a renaming of variables - used only by SignMerge *)
    val renaming_equal : tp -> tp -> bool;

    exception UnifyFailure;
    val unify : tp * tp -> unit;

    type ('a, 'b) pterm;
    val type_to_pterm : tp -> (Const.const, Var.var) pterm;

end; (* signature TYPE *)
