(* unify_llambda.fun -  This implements the generalized variable/	*)
(* unification as described by Dale Miller and postpones all other	*)
(* kinds of unification problems (solvable or not)			*)

(* Copyright (c) 1991,1994,1995 by Carnegie Mellon University		*)
(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Authors:								*)
(*	Frank Pfenning <fp@cs.cmu.edu>					*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

functor UnifyLlambda
    (structure Constraints : CONSTRAINTS_TYPES
     structure LTerm : LTERM
     structure UU : UUTILS

     (* psw remove *)
     structure Debug : DEBUG
     sharing type LTerm.lterm = Debug.lterm

     sharing type Constraints.dpair = UU.dpair
     sharing type LTerm.Type.tp = Constraints.tp
     sharing type LTerm.lterm = UU.lterm = Constraints.lterm)
	 : SIMPLIFY =
struct

local
    open Constraints;
in

    type constraint = Constraints.constraint;

    exception NonUnifiable = UU.NonUnifiable;

    fun rev_append nil k = k
      | rev_append (x::l) k = rev_append l (x::k)

(*
    fun ms_at anno M = "(" ^ anno ^ " " ^ (Print.debug (bare_term M)) ^ ")";
    fun ms_anno (M as Flex _) = ms_at "Flex" M
      | ms_anno (M as Rigid _) = ms_at "Rigid" M
      | ms_anno (M as Gvar _) = ms_at "Gvar" M
      | ms_anno (M as Abstraction _) = ms_at "Abstraction" M
      | ms_anno (M as Any _) = ms_at "Any" M;

    fun ms_dpair (DPair (M, N)) =
	"Dpair (" ^ (ms_anno M) ^ ", " ^ (ms_anno N) ^ ")"
    fun ms_dset (pair :: dset) =
	(ms_dpair pair) ^ " :: " ^ (ms_dset dset)
      | ms_dset nil = "nil\n"
    and print_dset dset =
	print (ms_dset dset);
*)

    (* simplify should only be called on *correctly* annotated
     * terms - i.e., we may need to reannotate some terms after making
     * an instantiation. *)
    fun simplify [] delayed = rev delayed
      | simplify (dpair :: dset) delayed =
	let
	    fun rigid_rigid ((M_head, M_args), (N_head, N_args)) =
		if LTerm.equal_head M_head N_head then
		    let
			fun rr (nil, nil) = dset
			  | rr (M :: rest1, N :: rest2) = 
			    (DPair (Any M, Any N)) :: (rr (rest1, rest2))
			  | rr _ = raise NonUnifiable
		    in
			(LTerm.Type.unify (LTerm.type_of M_head,
					   LTerm.type_of N_head);
			 simplify (rr (M_args, N_args)) delayed)
			handle LTerm.Type.UnifyFailure => raise NonUnifiable
		    end
		else
		    raise NonUnifiable

	    fun intersect_position_args (tp, nil, nil) = (tp, nil, false)
	      | intersect_position_args (tp, a1 :: args1, a2 :: args2) =
		let
		    val (t1, t2) =
			case (LTerm.Type.destruct_arrow tp) of
			    SOME tps => tps
			  | NONE =>
				raise Basic.InternalError
				"intersect_position_args: NotArrow"
		    val (tp', args, restrict) =
			intersect_position_args (t2, args1, args2)
		in
		    if LTerm.equal_head a1 a2 then
			(LTerm.Type.construct_arrow (t1, tp'), a1 :: args,
			 restrict)
		    else
			(tp', args, true)
		end
	      | intersect_position_args _ =
		raise Basic.InternalError "intersect_position_args called with\
				     \lists of different lengths"

	    fun intersect_args (tp, args1, args2, newer_evar) =
		let
		    fun ia (tp, nil) = (tp, nil)
		      | ia (tp, arg :: args) =
			let
			    val (t1, t2) =
				(case (LTerm.Type.destruct_arrow tp) of
				     SOME tps => tps
				   | NONE => 
					 raise Basic.InternalError
					 "intersect_args: NotArrow")

			    val (tp', args') =
				ia (t2, args)
			in
			    if (Lib.List.exists
				(LTerm.equal_head arg) args2 orelse
				LTerm.legal_binding (newer_evar, arg)) then
				(LTerm.Type.construct_arrow (t1, tp'),
				 arg :: args')
			    else
				(tp', args')
			end
		in
		    ia (tp, args1)
		end 

	    fun gvar_gvar ((M_head, M_args), (N_head, N_args)) =

		if LTerm.equal_head M_head N_head then
		     
		    (* either gvar_gvar_same or gvar_identity *)
		    (case (intersect_position_args
			   (LTerm.type_of M_head, M_args, N_args)) of
			 
			 (* gvar_identity - do nothing to this pair *)
			 (_, _, false) =>
			     simplify dset delayed

		       (* gvar_gvar_same *) 
		       | (tp, args, _) =>
			     let
				 val head =
				     LTerm.make_evar_as (tp, M_head)
				 val body =
				     foldl (fn (M1, M2) =>
					    LTerm.construct_application
					    (M2, M1))
				     head args
				 val term = foldr UU.abst_over_uvar body M_args
			     in
				 (LTerm.instantiate_evar (M_head, term);
				  reannotate_and_simplify dset delayed)
			     end)

		(* gvar_gvar_diff *) 
		else
		    let
			val (older_head, older_args, newer_head, newer_args) =
			    if LTerm.older (M_head, N_head) then
				(M_head, M_args, N_head, N_args)
			    else
				(N_head, N_args, M_head, M_args)
				
			val (tp', args') =
			    intersect_args
			    (LTerm.type_of older_head,
			     older_args,
			     newer_args,
			     newer_head)
			    
			val evar' =
			    LTerm.make_evar_as
			    (tp', older_head)

			val body =
			    foldl (fn (M, N) =>
				   LTerm.construct_application (N, M))
			    evar' args'
			     
			val M_inst = foldr UU.abst_over_uvar body M_args
			val N_inst = foldr UU.abst_over_uvar body N_args

		    in
			(LTerm.instantiate_evar (M_head, M_inst);
			 LTerm.instantiate_evar (N_head, N_inst);
			 reannotate_and_simplify dset delayed)
		    end			(* psw - remove *)
			handle Basic.InternalError str =>
			    (print "Caught in intersect position\n";
			     raise Basic.InternalError str)


	    fun triv (head_args as (M_head, M_args), N) fail =
		if UU.quick_eoc (head_args, N) then
		    let (* should raise? *)
			val inst = foldr UU.abst_over_uvar_raise N M_args
		    in
			(LTerm.instantiate_evar (M_head, inst);
			 reannotate_and_simplify dset delayed)
		    end
		else
		    fail ()

	    fun gvar_flex (dp as (DPair (Gvar (_, M_head_args), Flex (N, _))))=
		triv (M_head_args, N)
		(fn () => simplify dset (dp :: delayed))
	      | gvar_flex _ =
 		raise Basic.InternalError "gvar_flex: argument not gvar flex pair"


	    fun gvar_rigid (dp as (Gvar (M, gvar as (M_head, M_args)),
			    r as Rigid (N, _))) =
		if UU.quick_eoc (gvar, N) then
		    let (* should raise? *)
			val inst = foldr UU.abst_over_uvar_raise N M_args
		    in
			(LTerm.instantiate_evar (M_head, inst);
			 reannotate_and_simplify dset delayed)
		    end
		else
		    let
			val (N', dset') =
			    UU.extended_occurs_check (gvar, N, dset)
			val inst = foldr UU.abst_over_uvar_raise N' M_args
		    in
			(LTerm.instantiate_evar (M_head, inst);
			 reannotate_and_simplify dset' delayed)
		    end

	    and lam_any (Abstraction ((tp, name), M), Abstraction (_, N)) =
		let
		    val uvar = LTerm.new_uvar (tp, name)
		in
		    simplify 
		    ((DPair (Any (LTerm.construct_application (M, uvar)),
			     Any (LTerm.construct_application
				  (N, uvar)))) :: dset)
		    delayed 
		end

	      | lam_any (Abstraction ((tp, name), M), annoN) =
		let
		    val uvar = LTerm.new_uvar (tp, name)
		in
		    simplify
		    ((DPair (Any (LTerm.construct_application (M, uvar)),
			     Any (LTerm.construct_application
				  (bare_term annoN, uvar))))
		     :: dset)
		    delayed
		end

	      | lam_any _ =
		raise Basic.InternalError
		"lam_any: argument not abstraction other pair"
		

	    and lam_gvar (pair as (Abstraction (_, N), Gvar (_, head_args))) =
		triv (head_args, N) (fn () => lam_any pair)
	      | lam_gvar _ =
		raise Basic.InternalError
		"lam_gvar: argument not abstraction gvar pair"

	    and
		(* classify unknowns *)
		simplify_dpair (dp as DPair (Any M, N)) =
		simplify_dpair (DPair (annotate M, N))

	      | simplify_dpair (DPair (M, Any N)) =
		simplify_dpair (DPair (M, annotate N))


	      (* rigid-rigid case *)
	      | simplify_dpair (dp as DPair (Rigid (_, M_head_args),
				       Rigid (_, N_head_args))) =
		rigid_rigid (M_head_args, N_head_args)

	      (* gvar-gvar case *)
	      | simplify_dpair (dp as (DPair (Gvar (_, M_head_args),
				       Gvar (_, N_head_args)))) =
		 gvar_gvar (M_head_args, N_head_args)

	      (* will these be checked more than once? Maybe convert
	       gvar -> flex? *)
              (* gvar_flex cases - triv or give up *)
 	      | simplify_dpair (dp as (DPair (Gvar _, Flex _))) =
		 gvar_flex dp
	      | simplify_dpair (dp as DPair (fl as Flex _, gv as Gvar _)) =
		 gvar_flex (DPair (gv, fl))

	      (* gvar-lam cases - Triv or lam_any *)
	      | simplify_dpair (DPair (gv as Gvar _, lam as Abstraction _)) =
		lam_gvar (lam, gv)
	      | simplify_dpair (DPair (pair as (Abstraction _, Gvar _))) =
		lam_gvar pair
		
	      (* Gvar-Rigid *)
	      | simplify_dpair (DPair (dp as (Gvar _, Rigid _)))  =
		gvar_rigid dp
	      | simplify_dpair (DPair (r as Rigid _, gv as Gvar _)) = 
		gvar_rigid (gv, r)

	      (* Lam-Any *)
	      | simplify_dpair (dp as DPair (pair as (Abstraction _, _))) =
		lam_any pair
	      | simplify_dpair (DPair (any, abst as Abstraction _)) =
		lam_any (abst, any)

	      (* Flex-Any *)
	      | simplify_dpair (dp as DPair (Flex _, _)) =
		simplify dset (dp :: delayed)
	      | simplify_dpair (dp as DPair (_, Flex _)) =
		simplify dset (dp :: delayed)
		
	in
	    simplify_dpair dpair
	end

    and reannotate_and_simplify dset delayed =
	let
	    val dset' = (rev_append delayed dset)
	    val dset'' = reannotate_dset dset'
	in
	    simplify dset'' nil
	end

    and simplify_dset dset = reannotate_and_simplify dset nil;

    fun simplify_constraint (Con dset) =
	Con (simplify_dset dset)

end (* local *)
end; (* functor UnifyLlambda *)
