(* unparse.fun - unparsing						*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Author:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)


functor Unparse
    (structure Formatter : FORMATTER
     structure Fixity : FIXITY
     structure PTerm : PTERM

     val max_prec : int)
	 : UNPARSE =
struct

    type format = Formatter.format;
    type ('a, 'b) pterm = ('a, 'b) PTerm.pterm;

    (* Mutate the Formatter structure so that it only indents one space *)
    val _ = Formatter.Indent := 1;

local
    open Formatter Fixity PTerm;
in


    fun parens fmt =
	Hbox [String "(", fmt, String ")"];

    fun unparse (Evar f) = f
      | unparse (Uvar f) = f
      | unparse (Const f) = f
      | unparse (M as Lam _) = unparse_lam (M, [])
      | unparse (M as App (Const _, Lam _)) =
	unparse_bind_prefix (M, nil)
      | unparse (M as App _) =
	unparse_app (M, [])
      | unparse (M as Oper _) =
	unparse_oper M

    and unparse_lam (Lam (b, M), ls) =
	unparse_lam
	(M, (ls @
	     ((if null ls then [] else [Break]) @ [b, String "\\"])))
      | unparse_lam (M, ls) =
	HOVbox [Hbox ls, Break, unparse M]

    and unparse_bind_prefix (App (Const f, Lam (b, M)), ls) =
	unparse_bind_prefix
	(M, (ls @
	     ((if null ls then [] else [Break]) @
	       [f, Break, b, String "\\"])))
      | unparse_bind_prefix (M, ls) =
	HOVbox [Hbox ls, Break, unparse M]

    and unparse_app (M as App (Const _, Lam _), ls) =
	HVbox ((parens (unparse_bind_prefix (M, nil))) :: ls)
      | unparse_app (App (M, N as Lam _), ls) =
	unparse_app (M, Break :: (parens (unparse_lam (N, nil))) :: ls)
      (* Could be bind_prefix or just an app. Therefore we use unparse *)
      | unparse_app (App (M, N as App _), ls) =
	unparse_app (M, Break :: (parens (unparse N)) :: ls)
      | unparse_app (App (M, N as Oper _), ls) =
	unparse_app (M, Break :: (parens (unparse_oper N)) :: ls)
      | unparse_app (App (M, N), ls) =
	unparse_app (M, Break :: (unparse N) :: ls)
      | unparse_app (M as Oper _, ls) =
	HVbox ((parens (unparse_oper M)) :: ls)
      (* Term should be in beta-normal form, so Lam is not possible here *)
      | unparse_app (M, ls) =
	HVbox ((unparse M) :: ls)

    and unparse_oper (Oper (f, (prec1, _), M, N)) =
	let
	    fun up (M as Lam _, _) =
		parens (unparse_lam (M, nil))
	      | up (M as Oper (_, (prec2, assoc2), _, _), subtree) =
		(if (prec2 < prec1) orelse
		    ((prec2 = prec1) andalso (assoc2 <> subtree)) then
		     parens
		 else
		     Lib.Misc.id)
		(unparse_oper M)
	      | up (M as (App (Const _, Lam _)), _) =
		parens (unparse_bind_prefix (M, nil))
	      | up (M, _) =
		unparse M
	in
	    HOVbox [up (M, Left), Break, f, Break, up (N, Right)]
	end
      | unparse_oper _ =
	raise Basic.InternalError "unparse_oper";

end (* local open Formatter *)
end; (* functor UnParse *)
