(* comp_table.fun - Table which stores compiled (i.e. built-in)		*)
(* lambdaProlog predicates.						*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Author:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

functor CompTable
    (structure Lam : LAM
     structure IU : IU
     structure Module : MODULE

     sharing type Module.const = Lam.const)
	 : COMP_TABLE =
struct

    type tp = Lam.tp;
    type lterm = Lam.lterm;
    type const = Lam.const;
    type module = Module.module;
    type compiled_pred = IU.compiled_pred;
    
    val comp_table : (const, compiled_pred) Lib.Table.table = 
	Lib.Table.mk_table (Lam.Const.hash_const,
			Lib.Misc.uncurry Lam.Const.equal);

    (* store (const, pred) simply (destructively) associates the	*)
    (* constant const with the predicate pred, for later retrieval by	*)
    (* lookup.								*)
    fun store (const, pred) =
	Lib.Table.insert comp_table (const, pred);

    (* make module (name, pred) make performs a store on the constant	*)
    (* associated with name in module, and the predicate pred.		*)
    fun make module (name, func) =
	let
	    val sign_entry =
		case (Module.sign_lookup [module] name) of
		    SOME (Module.Con c) =>
			c
		  | _ => raise Basic.InternalError "CompTable.make"
	in
	    (store (sign_entry, func);
	     sign_entry)
	end;

    (* find head optionally returns the predicate associated with the	*)
    (* constant head.							*)
    fun find head =
	Lib.Table.find comp_table head;

end; (* functor CompTable *)

