(* comp_table.sig - signature for association table which holds		*)
(* compiled (i.e. built-in) predicates.					*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Authors:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

signature COMP_TABLE =
sig

    type const;				(* constants *)
    type lterm;				(* lambda-terms *)
    type tp;				(* type of lterms *)
    type module;			(* lambda-Prolog modules *)
    type compiled_pred;			(* type of built-in predicates *)
	
    (* Stores a built-in predicate using its head as a key, 
     * for later lookup by find *)
    val store : const * compiled_pred -> unit;

    (* Looks up the constant with name specified by the string argument in
     * the module argument, performs a store, and returns the constant. *)
    val make : module -> string * compiled_pred -> const;

    (* Given the head of a term, finds predicate associated
     * with it, if any. *)
    val find : const -> compiled_pred option;
	    
end; (* signature COMP_TABLE *)
