(* error.fun - defines error datatype and various functions for		*)
(* signaling and handling errors.					*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Authors:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

functor Error (structure Location : LOCATION) : ERROR =
struct

	type location = Location.location;

	datatype format =
	    STRING of string
	  | INT of int
	  | BOOL of bool
	  | REAL of real;

	datatype error =
	    ParseError of error
	  | Parse of string * format list
	  | Location of location * error
	  | Illegal of string * format list
	  | TypeCheckFail of string
	  | UnknownConstant of string
	  | UnknownModule of string
	  | UnknownSwitch of string;

	exception Error;

	local
	    val error_list : error list ref = ref [];
	in
	    fun error err =
		error_list := (! error_list) @ [err];

	    fun fatal_error err =
		(error err;
		 raise Error);
		
	    fun handle_errors func =
		(app func (! error_list);
		 error_list := []);

	    fun errors_waiting () =
		not (null (! error_list));
		
	end; (* local val error_list ... *)

end; (* functor Error *)
