(* error.sig - signature for structure which defines error datatype and	*)
(* operations there upon.						*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Authors:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

signature ERROR =
    sig

	type location;

	datatype format =
	    STRING of string
	  | INT of int
	  | BOOL of bool
	  | REAL of real;

	datatype error =
	    ParseError of error
	  | Parse of string * format list
	  | Location of location * error
	  | Illegal of string * format list
	  | TypeCheckFail of string
	  | UnknownConstant of string
	  | UnknownModule of string
	  | UnknownSwitch of string;

	(* Raises an error and (as the type implies) does not return. *)
	val fatal_error : error -> 'a;
	(* Signals that an error has occured. *)
	val error : error -> unit;

	exception Error;
	(* The Error structure maintains a list of errors which have	*)
	(* been signaled; handle_errors makes those errors available to	*)
	(* argument function and then deletes them.			*)
	val handle_errors : (error -> unit) -> unit;

	(* True iff the internal list of errors is non-empty. *)
	val errors_waiting : unit -> bool;
    end;

