(* help.fun - A rudimentary, simple, temporary help facility for the	*)
(* loader.								*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Author:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)


functor Help
    (structure TerminalIO : TERMINAL_IO
     structure Formatter : FORMATTER
     structure Error : ERROR)
	 : HELP =
struct

    val help_table : (string, string) Lib.Table.table =
	Lib.Table.mk_table (Lib.String.hash_string, op =);

    fun general () =
	TerminalIO.message
(
"\n\
\This help facility describes the commands available at the loader\n\
\level. To find out more about a particular topic, enter:\n\n\
\\t#help <topic>.\n\n\
\where <topic> is one of the following:\n\n" ^
(Formatter.makestring_fmt
 (Formatter.Hbox
  [Formatter.Spaces 8, 
   (Formatter.HVbox
    (tl
     (Lib.List.flatten
      (map (fn (x, _) => [Formatter.Break, Formatter.String x])
       (Lib.Table.list_items help_table)))))])) ^ "\n")

    fun lookup topic =
	case (Lib.Table.find help_table topic) of
	    NONE =>
		Error.fatal_error
		(Error.Illegal
		 ("No help available for topic \"%s\"", [Error.STRING topic]))
	  | SOME help =>
		TerminalIO.message help;

    val load =
"#load <file_name>.\n\
\\tIf <file_name> is a absolute path, then the loader attempts to\n\
\read <file_name> as a loader script, just as if the contents of the\n\
\file had been read from the standard input.  If <file_name> is not\n\
\absolute, the loader appends each path contained in the path switch\n\
\variable (see below) to <file_name> and the attempts to read the\n\
\resulting path and file, until a file is successfully found.\n";

    val help =
"#help <topic>\n\
\\tDisplay help on <topic>. Enter \"#help.\" for more information and a\n\
\list of topics.\n";

    val show =
"#show <switch_name>.\n\
\\tDisplays the value of the switch designated by\n\
\<switch_name>. Signals an error if <switch_name> does not exist.\n\n\
\#show.\n\
\\tDisplays the value of all switches known to the system.\n";

    val set =
"#set <switch_name> <v_1> <v_2> <v_3> ... <v_n>.\n\
\\tEach <v_i> is a strings or switch identifier, and n >= 1.\n\
\Sets the value of the switch <switch_name> to the string obtained by\n\
\concatenating the string value of each <v_i>. The string value of a\n\
\string is simply the string itself, while the string value of a switch\n\
\identifier is the value of that switch if the switch exists, and\n\
\undefined otherwise. For example:\n\n\
\Terzo> #show path.\n\
\path\t\t/usr/local/lib/lProlog/ /stuff/\n\
\Terzo> #set path \"/home/me/my_lProlog_files/ \" path.\n\
\Terzo> #show path.\n\
\path\t\t/home/me/my_lProlog_files/ /usr/local/lib/lProlog/ /stuff/\n";

    val begin =
"#begin.\n\
\\tTells the loader to read zero or more modules declarations\n\
\from the current input stream, until a matching #end statement\n\
\is read. See #end.\n";

    val end_command =
"#end.\n\
\\tTells the loader to stop reading module declarations from the\n\
\current input stream, or tells the loader to stop reading interactive\n\
\queries. See #begin.\n";

    val query =
"#query <module_list> <term>.\n\
\\t<module_list> is a comma separated list of module names, and <term>\n\
\is any term. Initiates the single query <term> against the\n\
\context formed by merging the modules in <module_list>.\n\n\
\#query <module_list>.\n\
\\tStarts an interactive read-query-print loop with the context\n\
\formed by merging the modules in <module_list>.\n\n\
\#query.\n\
\\tStarts an interactive read-query-print loop with the System\n\
\module as the context.\n";

    val quit =
"#quit.\n\
\\tExists the Terzo interpreter.\n";

    val print =
"#print <module>.\n\
\\tPrints the signature of <module>.\n";

    val switches =
"Loader Switches\n\
\---------------\n\
\\tThe Loader switches are set and displayed with the #set and\n\
\#show commands.  They are:\n\
\\n\
\path\n\
\\tThe path variable is intended to contain a list of\n\
\directories in which the loader should search for files when the the\n\
\#load command is used.  It is initially set to the value of the\n\
\environment variable $TERZO_PATH, if it is set, and\n\
\/usr/local/lib/Terzo/lib otherwise.\n\
\\n\
\print_sigs\n\
\\tThis variable controls whether or not a module's signature is\n\
\printed when it is read.  The valid values of this switch are \"on\" and\n\
\\"off\". It is initially set to \"off\".\n\
\\n\
\primary_loader_prompt\n\
\\tThe value of this variable is printed as a primary prompt at\n\
\the loader level. Initially set to \"Terzo> \".\n\
\\n\
\secondary_loader_prompt\n\
\\tThe value of this variable is printed as a secondary prompt at\n\
\the loader level. Initially set to \"     > \".\n\
\\n\
\print_abst_types\n\
\\tThis variable controls whether or not the types of bound\n\
\variables are printed when printing abstractions. The only valid\n\
\values of this switch are \"on\" and \"off\". Initially set to \"off\".\n\
\\n\
\print_types\n\
\\tThis variable controls whether or not the types of answer\n\
\substitutions are printed with the substitution. The only valid\n\
\values of this switch are \"on\" and \"off\". Initially set to \"off\".\n\
\\n\
\primary_query_prompt\n\
\\tThe value of this variable is printed as a primary prompt at\n\
\the interactive query interpreter level. Initially set to \"?- \".\n\
\\n\
\secondary_query_prompt\n\
\\tThe value of this variable is printed as a secondary prompt\n\
\at the interactive query interpreter level. Initially set to \" - \".\n\
\\n\
\off\n\
\\tEvaluates to \"off\". Cannot be set.\n\
\\n\
\on\n\
\\tEvaluates to \"on\". Cannot be set.\n\
\\n\
\all_solutions\n\
\\tControls whether or not all possible solutions to a query are\n\
\searched for immediately, without prompting. The only valid values of\n\
\this switch are \"on\" and \"off\". Initially set to \"off\".\n\
\\n\
\warn_positive_built_in\n\
\\tIf the value of this variable is set to \"on\" a warning is\n\
\printed when a constant is declared in a module which has a positive\n\
\occurrence of a built in type in its type.  For instance, if mod1 has a\n\
\constant f with type int -> int, then the following message will be\n\
\printed when mod1 is elaborated:\n\
\\n\
\Warning: Positive occurrence of built-in kind \"int\" found in type of \"f\".\n\
\\n\
\This warning is intended to make it easier to spot constants which\n\
\will cause trouble with the 'is' predicate. The only valid values of\n\
\this switch are \"on\" and \"off\". Initially set to \"on\".\n"

    val topics =
	[("load", load),
	 ("show", show),
	 ("help", help),
	 ("set", set),
	 ("query", query),
	 ("begin", begin),
	 ("end", end_command),
	 ("print", print),
	 ("quit", quit),
	 ("switches", switches)];

    val _ = app (Lib.Table.insert help_table) topics;

end;

