(* interpreter_utils.sig - signature for misc. utilities used by the	*)
(* query engine.							*)

(* Copyright (c) 1991,1994,1995 by Carnegie Mellon University		*)
(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Authors:								*)
(*	Frank Pfenning <fp@cs.cmu.edu>					*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

signature IU =
    sig

	type lterm;			(* lambda term *)
	type const;			(* constants *)
	type tp;			(* type *)
	type bi_const;			(* built in constants *)
	type module;			(* lambdaProlog modules *)
	type constraint;		(* flex-flex pairs *)
	type clause;			(* clause *)
	type env;			(* name environment *)
	    
	(* Interpreter record *)
	datatype i_record =
	    IR of
	    {modules : module list,
	     clauses : clause list,
	     env : env,
	     uvars : const list,	(* currently active uvars *)
	     ctag : exn,		(* The ctag exception is used
					   to impliment cut (!) *)
	     traced : lterm list};

	
	(* The type of built-in predicates, including logical constants *)
	datatype compiled_pred =
	    GFunc of
	    (tp *			(* type of head of arg *)
	     lterm list) *		(* args *)
	    i_record *			(* record *)
	    constraint *		(* con *)
	    (constraint -> unit)	(* sc *)
	    -> unit;

	val need : string -> 'a option -> 'a;

	(* The theFoo family of functions are destructors for built-in
	 * constants. They raise Basic.InternalError if the argument is
	 * not of the type specified. *)
	val theString : lterm -> string option;
	val theReal : lterm -> real option;
	val theInt : lterm -> int option;
	val theInStream : lterm -> Lib.IO.instream option;
	val theOutStream : lterm -> Lib.IO.outstream option;

	(* Each makeFoo function is a constructor for Foo. *)
	val makeString : string -> lterm;
	val makeBi : bi_const -> lterm;
	val makeReal : real -> lterm;
	val makeInt : int -> lterm;

	(* theAbstraction takes a type t1 and a term of type t1 -> t2
	 * and makes an explicit abtraction, eta-expanding, if
	 * nexessary. theAbstraction returns the binder of the abstraction
	 * and the body of the abstraction. *)
	val theAbstraction : tp -> lterm -> (tp * string option) * lterm;

	(* Finds the constant with name specified by the string argument
	 * in the module argument. Raises Basic.InternalError if no such
	 * constant exists. *)
	val get_const : module -> string -> lterm;

	(* This function is to be called by the interpreter if it finds
	 * a built-in or logical constant with incorrect args. *)
	val unexpected : lterm -> 'a;

	(* The following functions are used to insert new object into
	 * existing interpreter records.  add_FOO (new_FOO, record)
	 * will return record' which is identical to record, except
	 * that the FOO field = new_FOO *)
	val add_clauses : (clause list * i_record) -> i_record;
	val add_modules : (module list * i_record) -> i_record;
	val add_ctag : (exn * i_record) -> i_record;
	val add_uvars : (const list * i_record) -> i_record;
	val add_traced : (lterm list * i_record) -> i_record;

	(* Creates a binary compiled predicate from a destructor and a
	 * predicate. *)
	val bin_pred : (lterm -> 'a) -> ('a * 'a -> bool) -> compiled_pred;
	     
	(* Takes a type of the form (t1 -> t2) -> t3 and returns t1. Raises
	 * Basic.InternalError if the type is of the wrong form. *)
	val arg_arg_type : tp -> tp;

    end; (* signature IU *)
