(* logicals.fun - Logical constants					*)

(* Copyright (c) 1991,1994,1995 by Carnegie Mellon University		*)
(* Copyright (c) 1994,1995 by AT&T Bell Laboratories			*)
(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Authors:								*)
(*	Amy Felty <felty@bell-labs.com>					*)
(*	Frank Pfenning <fp@cs.cmu.edu>					*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

functor Logicals
    (structure Module : MODULE
     structure Lam : LAM

     val lg : Module.module

     sharing type Lam.const = Module.const
     sharing type Module.tp_const = Lam.Type.Const.const)
	 : LOGICALS =
struct

    type const = Lam.const;
    type tp = Lam.tp;

local
    open Lam
in
    fun get_const str =
	case (Module.sign_lookup [lg] str) of
	    NONE =>
		raise Basic.InternalError
		    ("Logicals: " ^ str ^ " not found.\n")
	  | SOME (Module.Con c) =>
		c
	  | _ => 
		raise Basic.InternalError
		    ("Logicals: " ^ str ^ " is not a constant.\n");
								      
    val pred_type =
	Type.construct_const
	(case (Module.sign_lookup [lg] "o") of
	     SOME (Module.TypeCon tc) => tc
	   | _ => raise Basic.InternalError "Logicals: pred_type.\n");

    val ttrue		=	get_const "true";
    val comma		=	get_const ",";
    val ampersand	=	get_const "&";
    val semicolon	=	get_const ";";
    val arrow		=	get_const "=>";
    val backarrow	=	get_const ":-";
    val pi		=	get_const "pi";
    val sigma		=	get_const "sigma";

    val truth		=	ttrue;
    val conjunction	=	comma;
    val disjunction	=	semicolon;
    val implication	=	arrow;
    val uquant		=	pi;
    val equant		=	sigma;

    fun is_truth c =
	Const.equal c ttrue;

    fun is_conjunction c =
	Const.equal c comma orelse Const.equal c ampersand;

    fun is_disjunction c =
	Const.equal c semicolon;

    fun is_implication c =
	Const.equal c arrow orelse Const.equal c backarrow

    fun is_uquant c =
	Const.equal c pi;

    fun is_equant c =
	Const.equal c sigma;

	
    fun std_order c (M, N) =
	if Const.equal c arrow then
	    (M, N)
	else
	    (N, M);

end (* local open Lam *)
end  (* functor Logicals *)
