(* module.sig - module manipulation					*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Author:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

signature MODULE =
    sig

	type module;			(* type of modules *)
	type lterm;			(* type of lambda terms *)
	type const;			(* type of constants *)
	type tp;			(* type of types *)
	type tp_const;			(* type of type constants *)

        datatype clause =
	    Clause of
	    const *			(* constant head of 
					 * term head of implication *)
	    (tp * string option) list *	(* free vars *)
	    lterm *			(* head of implication *)
	    lterm;			(* body of implication *)

	datatype sign_entry =
	    TypeCon of tp_const
	  | Con of const;

	val new_module : string -> module;
	val remove_module : string -> unit;
	val lookup_module : string -> module option;
	val module_name : module -> string;

	val sign_lookup : module list -> string -> sign_entry option;
	val is_const : module list -> string -> bool;
	val sign_insert : module -> (string * sign_entry) -> unit;

	(* All TypeCons are listed first - this is a small hack so that
	 * SignMerge.sign_merge is easy to write. *)
	val sign_app : module -> (string * sign_entry -> unit) -> unit;

	val prog_lookup : module list -> const ->
	    (module list -> clause -> unit) -> unit;
	val prog_insert : module -> clause list -> unit;

	(* used for debugging *) 
	val prog_list : module -> (const * clause list) list;

	(* Instantiate locals, i.e. convert local constants to uvars with
	 * current time stamp. *)
	val inst_locals : module -> const list;

	val make_local : module -> string list -> unit;
	val make_localkind : module -> string list -> unit;

	val accumulate : module -> module list -> unit;
	val import : module -> module list -> unit;
    
	val print_sign : module -> unit;

    end; (* signature MODULE *)
