(* program.sig - clausification and abstraction, quantification, and	*)
(* substitution over free variables.					*)

(* Copyright (c) 1991,1994,1995 by Carnegie Mellon University		*)
(* Copyright (c) 1994,1995 by AT&T Bell Laboratories			*)
(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Authors:								*)
(*	Amy Felty <felty@bell-labs.com>					*)
(*	Frank Pfenning <fp@cs.cmu.edu>					*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

signature PROGRAM =
sig

    type sterm;				(* simple terms - built by Absyn *)
    type lterm;				(* lambda terms *)
    type const;				(* constants. also uvars *)
    type tp;				(* types *)
    type clause;			(* clauses *)

    val abst_over_fvar : (tp * string) * sterm -> sterm;

    (* freevars_to_uquant raw_term					*)
    (*		Takes the raw term raw_term, attempts to reconstruct	*)
    (* its type as o, converts it to an lterm, and universally		*)
    (* quantifies over its free variables.				*)
    val freevars_to_uquant :
	(tp * string) list * (tp * string) list * sterm	-> lterm;

    (* freevars_to_evars (raw_term, tp, uvars)				*)
    (*		Takes the raw term raw_term, attempts to reconstruct	*)
    (* its type as tp, converts is to an lterm, and replaces its free	*)
    (* variables with evars which may depend in uvars.			*)
    val freevars_to_evars :
	((tp * string) list * (tp * string) list * sterm) * tp * const list
		-> lterm list * lterm;

    val clausify : lterm -> clause list -> clause list;

    val terms_to_clauses : lterm list -> clause list;

end  (* signature PROGRAM *)
