(* sign_merge.fun - signature merging and local type constructor	*)
(* checking.								*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Author:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

functor SignMerge
    (structure Error : ERROR
     structure Lam : LAM
     structure TerminalIO : TERMINAL_IO
     structure Formatter : FORMATTER
     structure Switch : SWITCH
     structure Module : MODULE

     sharing type Lam.const = Module.const
     sharing type Module.tp_const = Lam.Type.Const.const)
	 : SIGN_MERGE =
struct

    (* Switch *)
    val warn_built_in = ref true
    val _ =
	Switch.make "warn_positive_built_in" (Switch.make_on_off warn_built_in)
    (* end Switch *)

    type module = Module.module;
    type tp_const = Module.tp_const;

    structure F = Formatter;

local
    open Error Lam Module;
in

    fun sign_merge mod1 mod2 =
	let
	    fun merge_item (cname, TypeCon tp_con1) =
		(case (sign_lookup [mod2] cname) of
		     NONE => ()
		   | SOME (TypeCon tp_con2) =>
			 if not (Type.Kind.equal (Type.Const.type_of tp_con1)
				 (Type.Const.type_of tp_con2)) then
			     error
			     (Illegal ("Differing kinds declared for \
			      \type constructor %s.", [STRING cname]))
			     
			 else if ((Type.Const.fixity tp_con1) <>
				  (Type.Const.fixity tp_con2)) then
			      error
			      (Illegal ("Differing fixities declared for %s.",
					[STRING cname]))
			     
			 else (* By golly, everything is OK! *)
			     Type.Const.merge_consts (tp_con1, tp_con2)
		   | SOME _ =>
			 error
			 (Illegal ("%s declared both as constant and\
			  \type constructor.", [STRING cname])))

	      | merge_item (cname, Con const1) =
	        (case (sign_lookup [mod2] cname) of
		     NONE => ()
		   | SOME (Con const2) =>
			 if not (Type.renaming_equal
				 (Const.type_of const1)
				 (Const.type_of const2)) then
			     error
			     (Illegal ("Differing types declared for %s.",
				       [STRING cname]))
			     
 			 else if ((Const.fixity const1) <>
				  (Const.fixity const2)) then
			     error
			     (Illegal ("Differing fixities declared for %s.",
				       [STRING cname]))
			     
			 else (* By golly, everything is OK! *)
			     Const.merge_consts (const1, const2)

		   | SOME _ =>
			 error
			 (Illegal ("%s declared both as constant and\
			  \type constructor.", [STRING cname])))
    in
        (* This only works if all TypeCons are listed first by sign_app *)
	sign_app mod1 merge_item
    end;


fun localkind_check (module, localtypes)  =
    let
	fun is_local item =
	    Lib.List.exists (Type.Const.equal item) localtypes

	fun check (_, TypeCon _) = ()
	  | check (cname, Con c) =
	    let
		val constrs = Type.constructors (Const.type_of c)

		fun find_local (constr, _) =
		    if is_local constr then
			error
			(Illegal ("Occurrence of local type constructor \"%s\"\
			 \ found in type of const \"%s\".",
			 [STRING (Type.Const.makestring_const constr),
			  STRING cname]))
		    else 
			()


		fun find_bi (constr, true) =
		    if Type.Const.is_bi constr then
			TerminalIO.message
			(F.makestring_fmt
			 (F.HVbox
			  [F.String "Warning:", F.Break,
			   F.String "Positive occurrence of built-in type",
			   F.String "\"",
			   F.String (Type.Const.makestring_const constr),
			   F.String "\"", F.Break, F.String "found in type of",
			   F.Break, F.String "\"", F.String cname,
			   F.String "\""]))
		    else
			()
		  | find_bi _ = ()
	    in
		(app find_local constrs;
		 if !warn_built_in then
		     app find_bi constrs
		 else
		     ())
	    end
    in
	Module.sign_app module check
    end;

end (* local *)

end; (* functor SignMerge *)
