(* switch.fun - Registry for User setable switches.			*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Author:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)


functor Switch
    (structure Error : ERROR
     structure Formatter : FORMATTER)
	 : SWITCH =
struct

    type switch = string;
	    
    val switch_tab : (string, (string -> unit) * (unit -> string )) Lib.Table.table
	= Lib.Table.mk_table (Lib.String.hash_string, op =);

    fun set switch value =
	case (Lib.Table.find switch_tab switch) of
	    NONE =>
		Error.fatal_error (Error.UnknownSwitch switch)
	  | SOME (set_func, _) => set_func value;

    fun show switch =
	case (Lib.Table.find switch_tab switch) of
	    NONE =>
		Error.fatal_error (Error.UnknownSwitch switch)
	  | SOME (_, show_func) => show_func ();


    fun exists switch =
	case (Lib.Table.find switch_tab switch) of
	    NONE => false
	  | SOME _ => true;


    fun make switch funcs =
	Lib.Table.insert switch_tab (switch, funcs);

(* This is broken 
local
    open Formatter
in
    fun print_all print =
	let
	    val switches = Lib.Table.list_items switch_tab
	    val switch_names =
		Vbox0 0 1 
		(foldl (fn ((switch, _), fmt_lst) =>
			(String switch) :: Break :: fmt_lst)
		 [String (#1 (hd switches))] (tl switches))
	    val switch_values =
		Vbox0 0 1
		(foldl (fn ((_, (_, vfunc)), fmt_lst) =>
			(String (vfunc ())) :: Break :: fmt_lst)
		  [String ((#2 (#2 (hd switches))) ())] (tl switches))
	in
	    print
	    (makestring_fmt (Hbox0 8 [switch_names, Break, switch_values]))
	end;
end (* local open formatter *)
*)

    fun makestring_switch (switch, value) =
	let
	    val len = size switch
	    fun make_space 0 = ""
	      | make_space i = " " ^ (make_space (i - 1))
	in
	    if len < 32 then
		switch ^ (make_space (32 - len)) ^ value
	    else
		switch ^ "\n\t\t\t\t" ^ value
	end

	
    fun show_all func =
	(Lib.Table.map (fn (name, (_, get)) => func (name, get ())) switch_tab;
	 ())

    fun explode str =
	Lib.String.tokenize " " str;

    fun implode ls =
	let
	    fun i (l::ls) "" =
		i ls l
	      | i (l::ls) str =
		i ls (str ^ " " ^ l)
	      | i [] str = str
	in
	    i ls ""
	end;

	
    fun make_on_off switch_ref =
	(fn str => switch_ref :=
	 (case str of
	      "on" => true
	    | "off" => false
	    | _ => 
		  Error.fatal_error
		  (Error.Illegal ("Malformed on/off switch.", []))),
	 fn () =>
	 (if (! switch_ref) then
	      "on"
	  else
	      "off"));
	

end; (* structure Switch *)

