(* top.fun - top level to Terzo interpreter.				*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Author:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

functor Top
    (structure ErrorPrint : ERROR_PRINT
     structure Error : ERROR
     structure Parse : PARSE
     structure TerminalIO : TERMINAL_IO
     structure Switch : SWITCH
     structure Script : SCRIPT

     sharing type Error.error = ErrorPrint.error
     sharing type Script.parse_stream = Parse.parse_stream)
	 : TOP =
struct


    val version = "1.2b";
    val build_date = Lib.Sys.date ();


    exception NoBase;

    fun top (args, env) =
	let
	    val stream =
		Parse.interactive_stream_init Lib.IO.std_in "std_in"
      

	    val base =
 		case (Lib.Env.get_value "TERZO_BASE") of
		    NONE => raise NoBase
		  | SOME base => base


	    val path_string =
		case (Lib.Env.get_value "TERZO_PATH") of
		    NONE => Lib.Dir.mk_path (base, "/lib/")
		  | SOME path => path

	    val startup_file =
		case (Lib.Env.get_value "TERZO_INITIAL") of
		    NONE => Lib.Dir.mk_path (base, "/lib/terzo.rc")
		  | SOME i => i

	    fun read_startup () =
		(let
		     val (close_func, stream) =
			 Parse.file_init startup_file
		 in
		     (Script.read_script stream;
		      close_func ())
		 end)
		     handle
		     IO.Io msg =>
			 TerminalIO.print_error
			 ("Error: Could not read initial file: " ^
			  startup_file ^ "")

		   | Error.Error => 
			 (Error.handle_errors ErrorPrint.error_print;
			  ())


	    fun loop () =
		if Basic.successful (Script.read_script stream) then
		    raise Lib.Signal.Return
		else
		    loop ()

	in
	
	    ((* Setup *)

	     TerminalIO.message ("Terzo lambda-Prolog, Version " ^ version ^
				 ", Built " ^ build_date);

	     (* *)
	     Switch.set "path" path_string;

	     (* Read the initial script, if one exists. *)
	     read_startup ();

	     Lib.Signal.handle_interrupt loop;
	     Lib.Process.success)
	end
    handle Basic.InternalError msg =>
	(TerminalIO.print_error ("Internal Error occured: " ^ msg);
	 Lib.Process.failure)
	 | NoBase =>
	(TerminalIO.print_error "TERZO_BASE variable must be set";
	 Lib.Process.failure)

end; (* functor Top *)
