(* lexer_interface.fun - Externally visible aspects of the lexer and	*)
(* parser								*)

(* Copyright (c) 1991,1994,1995 by Carnegie Mellon University		*)
(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Authors:								*)
(*	Frank Pfenning <fp@cs.cmu.edu>					*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

functor LexerInterface () : LEXER_INTERFACE =
struct

    datatype region = Region of {from : int * int, to : int * int}
    type pos = int;
    type location = string * region;
    type counter = pos ref * pos list ref;
    datatype lexarg = LA of string * counter;

    val empty_pos = 0;
      
    fun new_counter () =
	(ref 1, ref ([] : pos list));

    fun init_counter (line, newlines : pos list ref) =
	(line := 0;
	 newlines := [])

    fun next_line (line, newlines) newline_pos =
	(line := (! line) + 1; 
	 newlines := newline_pos :: !newlines);

    fun last_newline (_, ref newlines) =
	(case newlines of
	     nil => 0
	   | (pos::_) => pos)
	     
    fun search_pos (pos:pos, line, nil) = (line, pos)
      | search_pos (pos:pos, line, newline_pos::rest) =
	if pos > newline_pos then
	    (line, pos - newline_pos)
	else
	    search_pos (pos, line - 1, rest)

    fun make_region (ref line, ref newlines) (lpos, rpos) =
	Region {from = search_pos (lpos, line, newlines),
		to = search_pos (rpos, line, newlines)};

    fun makestring_region (Region {from = (lline, lcol), to = (rline, rcol)}) =
	(Lib.Convert.itoa lline) ^ "." ^ (Lib.Convert.itoa lcol)
	^ "-" ^ (Lib.Convert.itoa rline) ^ "." ^ (Lib.Convert.itoa rcol)

    fun make_location counter filename lrpos =
	(filename, make_region counter lrpos);

    fun makestring_location (filename, region) =
	filename ^ ":" ^ (makestring_region region);
    
    fun merge_locations ((filename, Region {from, ...}), (_, Region {to,...}))=
	(filename, Region {from = from, to = to});

end  (* functor LexerInterface *)
