(* lp.lex - ml-lex file for Terzo lambdaProlog				*)

(* Copyright (c) 1991,1994,1995 by Carnegie Mellon University		*)
(* Copyright (c) 1994,1995 by AT&T Bell Laboratories			*)
(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Authors:								*)
(*	Amy Felty <felty@bell-labs.com>					*)
(*	Elsa Gunter <elsa@research.att.com>				*)
(*	Frank Pfenning <fp@cs.cmu.edu>					*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

structure Tokens = Tokens
open Error LexerInterface
(* For ml-lex *)
type pos = pos
type svalue = Tokens.svalue
type ('a,'b) token = ('a,'b) Tokens.token
type lexresult= (svalue,pos) token
type arg = lexarg

(* Abrieviations *)
val size = Lib.String.size;
    
val commentNesting = ref 0;
(* last position will be inaccurate! *)
fun eof (LA (name, counter)) =
    let
	val lastpos = (last_newline counter) + 1
    in
	(if !commentNesting > 0 then
	     (commentNesting := 0;
	      Error.fatal_error
	      (Error.ParseError
	       (Error.Location
		(make_location counter name (lastpos, lastpos),
		 Error.Illegal ("unclosed comment.", [])))))
	else
	     ();
	 Tokens.EOF (lastpos, lastpos))
    end;

fun stripquotes s =
    Lib.String.substring (s, 1, Lib.String.size s - 2);

val str_ref = ref "";

(*
fun makeString (text, (LA (name, counter)), pos) =
    Lib.String.compressStr text
    handle BadArg =>
     Error.fatal_error
     (Error.ParseError
      (Error.Location
       (make_location counter name pos,
	Error.Illegal ("Bad string escape: %s.", [Error.STRING text]))));
*)
%%
%header (functor LPLexFun
	 (structure Tokens: LP_TOKENS
          structure TerminalIO : TERMINAL_IO
	  structure Error : ERROR
	  structure LexerInterface : LEXER_INTERFACE
	  sharing type LexerInterface.location = Error.location): ARG_LEXER);
%arg ((lexarg as (LexerInterface.LA (stream_name, counter))) : LexerInterface.lexarg);
%s COMMENT NCOMMENT STRING FORMAT;
sstart=#;


lcstart=[a-z!@$^=~`<>*+?|/]|\-;
ucstart=[A-Z_];
idchars={lcstart}|{ucstart}|[0-9'];
lcid={lcstart}{idchars}*;
ucid={ucstart}{idchars}*;
qchars=[^'\t\ \n\012];
quid='{qchars}*';
ws=[\t\ \012]*;
num=[0-9];
%%
<INITIAL>{ws}			=> (continue());

<INITIAL,FORMAT,NCOMMENT>\n	=> (next_line counter yypos;
				    continue ());
<INITIAL>"%"	=> (YYBEGIN COMMENT; continue ());
<INITIAL>"#!"	=> (YYBEGIN COMMENT; continue ());
<INITIAL>"%("	=> (commentNesting := (! commentNesting) + 1;
		    YYBEGIN NCOMMENT; continue ());

<INITIAL>"."    => (Tokens.DOT (yypos, yypos + 1));
<INITIAL>"("	=> (Tokens.LPAREN (yypos, yypos + 1));
<INITIAL>")"	=> (Tokens.RPAREN (yypos, yypos + 1));
<INITIAL>"->"	=> (Tokens.ARROW (yypos, yypos + 2));
<INITIAL>":"	=> (Tokens.COLON (yypos, yypos + 1));
<INITIAL>"\\"	=> (Tokens.BACKSLASH (yypos, yypos + 1));
<INITIAL>","	=> (Tokens.COMMA (yypos, yypos + 1));
<INITIAL>"_"	=> (Tokens.ANONYMOUS (yypos, yypos + 1));

<INITIAL>":-"	=> (Tokens.LCID (":-", yypos, yypos + 2));
<INITIAL>";"	=> (Tokens.LCID (";", yypos, yypos + 1));
<INITIAL>"&"	=> (Tokens.LCID ("&", yypos, yypos + 1));
<INITIAL>"="	=> (Tokens.LCID ("=", yypos, yypos + 1));
<INITIAL>"::"	=> (Tokens.LCID ("::", yypos, yypos + 2));
<INITIAL>"=:="	=> (Tokens.LCID ("=:=", yypos, yypos + 3));
<INITIAL>"=\\="	=> (Tokens.LCID ("=\\=", yypos, yypos + 3));

<INITIAL>"module"	=> (Tokens.MODULE (yypos, yypos + 6));
<INITIAL>"import"	=> (Tokens.IMPORT (yypos, yypos + 6));
<INITIAL>"accumulate"	=> (Tokens.ACCUMULATE (yypos, yypos + 10));

<INITIAL>{sstart}"load"	=> (Tokens.LOAD (yypos, yypos + 5));
<INITIAL>{sstart}"set"	=> (Tokens.SET (yypos, yypos + 4));
<INITIAL>{sstart}"show" => (Tokens.SHOW (yypos, yypos + 5));
<INITIAL>{sstart}"help" => (Tokens.HELP (yypos, yypos + 5));
<INITIAL>{sstart}"query"=> (Tokens.QUERY (yypos, yypos + 6));
<INITIAL>{sstart}"begin"=> (Tokens.BEGIN (yypos, yypos + 6));
<INITIAL>{sstart}"end"	=> (Tokens.END (yypos, yypos + 4));
<INITIAL>{sstart}"print"=> (Tokens.PRINT (yypos, yypos + 6));
<INITIAL>{sstart}"quit"=>  (Tokens.QUIT (yypos, yypos + 6));

<INITIAL>"type"		=> (Tokens.TYPE (yypos, yypos + 4));
<INITIAL>"local"	=> (Tokens.LOCAL (yypos, yypos + 5));
<INITIAL>"kind"		=> (Tokens.KIND (yypos, yypos + 4));
<INITIAL>"localkind"	=> (Tokens.LOCALKIND (yypos, yypos + 9));
<INITIAL>"infixl"	=> (Tokens.INFIXL(yypos,yypos+6));
<INITIAL>"infixr"	=> (Tokens.INFIXR(yypos,yypos+6));
<INITIAL>"infix"	=> (Tokens.INFIX(yypos,yypos+5));

<INITIAL>"int"		=> (Tokens.INTTYPE(yypos,yypos+3));
<INITIAL>"real"		=> (Tokens.REALTYPE (yypos, yypos + 4));
<INITIAL>"string"	=> (Tokens.STRINGTYPE (yypos, yypos + 6));
<INITIAL>"in_stream"	=> (Tokens.INSTREAMTYPE (yypos, yypos + 9));
<INITIAL>"out_stream"	=> (Tokens.OUTSTREAMTYPE (yypos, yypos + 10));

<INITIAL>\~?{num}+		=>
    (Tokens.INT (Lib.Convert.atoi yytext, yypos, yypos + size yytext)
     handle Lib.Convert.Convert =>
     (fatal_error
      (ParseError
       (Location
	(make_location counter stream_name (yypos, yypos + (size yytext)),
	 Illegal ("Integer too large.", []))))));

<INITIAL>\~?{num}+(\.{num}+|\~?E{num}+|\.{num}+\~?E{num}+)
				=>
    (Tokens.REAL (Lib.Convert.atof yytext, yypos, yypos + size yytext)
     handle Lib.Convert.Convert =>
     (fatal_error
      (ParseError
       (Location
	(make_location counter stream_name (yypos, yypos + (size yytext)),
	 Error.Illegal ("Unclosed string.", []))))));


<INITIAL>{lcid}			=> (Tokens.LCID
				    (yytext, yypos,
				     yypos + Lib.String.size yytext));
<INITIAL>{ucid}			=> (Tokens.UCID (yytext, yypos,
						 yypos + size yytext));
<INITIAL>{quid}			=> (Tokens.QUID (stripquotes yytext,yypos,
						 yypos + size yytext));


<INITIAL>\"			=> (YYBEGIN STRING;
				    str_ref := "";
				    continue ());

<STRING>[^"\\\n]+		=> (str_ref := (!str_ref) ^ yytext;
				    continue ());
<STRING>\\\n			=> (next_line counter yypos;
				    YYBEGIN FORMAT;
				    continue ());
<STRING>\\[\t\^L\ ]		=> (YYBEGIN FORMAT;
				    continue ());

<STRING>\\n			=> (str_ref := (!str_ref) ^ "\n";
				    continue ());
<STRING>\\t			=> (str_ref := (!str_ref) ^ "\t";
				    continue ());
<STRING>\\\\			=> (str_ref := (!str_ref) ^ "\\";
				    continue ());
<STRING>\\\"			=> (str_ref := (!str_ref) ^ "\"";
				    continue ());
<STRING>\\"^"[@-_]		=> (str_ref :=
				    (!str_ref) ^
				    (Lib.String.chr
				     ((Lib.String.ordof (yytext, 3) - 64)));
				    continue ());

<STRING>\\[0-9]{3}		=>
    (let
	 val escape_val = Lib.Convert.atoi (Lib.String.substring(yytext, 1, 3))
     in
	 if escape_val > 255 then
	     fatal_error
	     (ParseError
	      (Location
	       (make_location counter stream_name (yypos, yypos + 3),
	        Illegal ("Illegal string escape: %s.",[Error.STRING yytext]))))
	 else
	     (str_ref := (!str_ref) ^ (Lib.String.chr escape_val);
	      continue ())
     end);

<STRING>\"			=> (YYBEGIN INITIAL;
				    Tokens.STRING (!str_ref, yypos, yypos+1));
    

<STRING>(.|\n)			=>
    (fatal_error
     (ParseError
      (Location
       (make_location counter stream_name (yypos, yypos + 1),
        Illegal ("Unclosed string.", [])))));


<FORMAT>[\t\^L\ ]		=> (continue ());
<FORMAT>\\			=> (YYBEGIN STRING;
				    continue ());
<FORMAT>.		=>
    (fatal_error
     (ParseError
      (Location
       (make_location counter stream_name (yypos, yypos + 1),
        Illegal ("Unclosed string.", [])))));

    
<INITIAL>.	=> 
(TerminalIO.message
 ((makestring_location (make_location counter stream_name (yypos, yypos + 1)))^
  "Ignoring illegal character " ^ yytext);
 continue());

<COMMENT>\n			=> (next_line counter yypos;
				    YYBEGIN INITIAL;
				    continue());
<COMMENT>.			=> (continue());

<NCOMMENT>"%("			=> (commentNesting := (! commentNesting) + 1;
				    continue());
<NCOMMENT>")%"			=> (commentNesting := (! commentNesting) - 1;
				    if (! commentNesting) = 0 then
					YYBEGIN INITIAL
				    else
					();
					continue());
<NCOMMENT>.			=> (continue());

