functor LPLexFun
	 (structure Tokens: LP_TOKENS
          structure TerminalIO : TERMINAL_IO
	  structure Error : ERROR
	  structure LexerInterface : LEXER_INTERFACE
	  sharing type LexerInterface.location = Error.location): ARG_LEXER=
   struct
    structure UserDeclarations =
      struct
(* lp.lex - ml-lex file for Terzo lambdaProlog				*)

(* Copyright (c) 1991,1994,1995 by Carnegie Mellon University		*)
(* Copyright (c) 1994,1995 by AT&T Bell Laboratories			*)
(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Authors:								*)
(*	Amy Felty <felty@bell-labs.com>					*)
(*	Elsa Gunter <elsa@research.att.com>				*)
(*	Frank Pfenning <fp@cs.cmu.edu>					*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

structure Tokens = Tokens
open Error LexerInterface
(* For ml-lex *)
type pos = pos
type svalue = Tokens.svalue
type ('a,'b) token = ('a,'b) Tokens.token
type lexresult= (svalue,pos) token
type arg = lexarg

(* Abrieviations *)
val size = Lib.String.size;
    
val commentNesting = ref 0;
(* last position will be inaccurate! *)
fun eof (LA (name, counter)) =
    let
	val lastpos = (last_newline counter) + 1
    in
	(if !commentNesting > 0 then
	     (commentNesting := 0;
	      Error.fatal_error
	      (Error.ParseError
	       (Error.Location
		(make_location counter name (lastpos, lastpos),
		 Error.Illegal ("unclosed comment.", [])))))
	else
	     ();
	 Tokens.EOF (lastpos, lastpos))
    end;

fun stripquotes s =
    Lib.String.substring (s, 1, Lib.String.size s - 2);

val str_ref = ref "";

(*
fun makeString (text, (LA (name, counter)), pos) =
    Lib.String.compressStr text
    handle BadArg =>
     Error.fatal_error
     (Error.ParseError
      (Error.Location
       (make_location counter name pos,
	Error.Illegal ("Bad string escape: %s.", [Error.STRING text]))));
*)
end (* end of user routines *)
exception LexError (* raised if illegal leaf action tried *)
structure Internal =
	struct

datatype yyfinstate = N of int
type statedata = {fin : yyfinstate list, trans: string}
(* transition & final state table *)
val tab = let
val s = [ 
 (0, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (1, 
"\011\011\011\011\011\011\011\011\011\164\166\011\164\011\011\011\
\\011\011\011\011\011\011\011\011\011\011\011\011\011\011\011\011\
\\164\023\163\127\023\125\124\121\120\119\023\023\118\116\115\023\
\\110\110\110\110\110\110\110\110\110\110\107\106\023\101\023\023\
\\023\100\100\100\100\100\100\100\100\100\100\100\100\100\100\100\
\\100\100\100\100\100\100\100\100\100\100\100\011\099\011\023\097\
\\023\087\023\023\023\023\023\023\023\067\023\063\054\048\023\038\
\\023\023\034\028\024\023\023\023\023\023\023\011\023\011\012\011\
\\011"
),
 (3, 
"\167\167\167\167\167\167\167\167\167\167\168\167\167\167\167\167\
\\167\167\167\167\167\167\167\167\167\167\167\167\167\167\167\167\
\\167\167\167\167\167\167\167\167\167\167\167\167\167\167\167\167\
\\167\167\167\167\167\167\167\167\167\167\167\167\167\167\167\167\
\\167\167\167\167\167\167\167\167\167\167\167\167\167\167\167\167\
\\167\167\167\167\167\167\167\167\167\167\167\167\167\167\167\167\
\\167\167\167\167\167\167\167\167\167\167\167\167\167\167\167\167\
\\167\167\167\167\167\167\167\167\167\167\167\167\167\167\167\167\
\\167"
),
 (5, 
"\169\169\169\169\169\169\169\169\169\169\166\169\169\169\169\169\
\\169\169\169\169\169\169\169\169\169\169\169\169\169\169\169\169\
\\169\169\169\169\169\172\169\169\169\170\169\169\169\169\169\169\
\\169\169\169\169\169\169\169\169\169\169\169\169\169\169\169\169\
\\169\169\169\169\169\169\169\169\169\169\169\169\169\169\169\169\
\\169\169\169\169\169\169\169\169\169\169\169\169\169\169\169\169\
\\169\169\169\169\169\169\169\169\169\169\169\169\169\169\169\169\
\\169\169\169\169\169\169\169\169\169\169\169\169\169\169\169\169\
\\169"
),
 (7, 
"\174\174\174\174\174\174\174\174\174\174\189\174\174\174\174\174\
\\174\174\174\174\174\174\174\174\174\174\174\174\174\174\174\174\
\\174\174\188\174\174\174\174\174\174\174\174\174\174\174\174\174\
\\174\174\174\174\174\174\174\174\174\174\174\174\174\174\174\174\
\\174\174\174\174\174\174\174\174\174\174\174\174\174\174\174\174\
\\174\174\174\174\174\174\174\174\174\174\174\174\176\174\174\174\
\\174\174\174\174\174\174\174\174\174\174\174\174\174\174\174\174\
\\174\174\174\174\174\174\174\174\174\174\174\174\174\174\174\174\
\\174"
),
 (9, 
"\190\190\190\190\190\190\190\190\190\191\166\190\190\190\190\190\
\\190\190\190\190\190\190\190\190\190\190\190\190\190\190\190\190\
\\191\190\190\190\190\190\190\190\190\190\190\190\190\190\190\190\
\\190\190\190\190\190\190\190\190\190\190\190\190\190\190\190\190\
\\190\190\190\190\190\190\190\190\190\190\190\190\191\190\190\190\
\\190\190\190\190\190\190\190\190\190\190\190\190\192\190\191\190\
\\190\190\190\190\190\190\190\190\190\190\190\190\190\190\190\190\
\\190\190\190\190\190\190\190\190\190\190\190\190\190\190\190\190\
\\190"
),
 (12, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\014\014\014\014\014\014\014\014\014\014\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (13, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (14, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\018\013\
\\014\014\014\014\014\014\014\014\014\014\000\000\013\013\013\013\
\\013\013\013\013\013\016\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\015\000\
\\000"
),
 (15, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\016\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (16, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\017\017\017\017\017\017\017\017\017\017\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (18, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\019\019\019\019\019\019\019\019\019\019\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (19, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\019\019\019\019\019\019\019\019\019\019\000\000\000\000\000\000\
\\000\000\000\000\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\020\000\
\\000"
),
 (20, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (21, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\022\022\022\022\022\022\022\022\022\022\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (24, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\025\013\000\013\000\013\000\
\\000"
),
 (25, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\026\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (26, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\027\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (28, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\029\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (29, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\030\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (30, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\031\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (31, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\032\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (32, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\033\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (34, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\035\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (35, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\036\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (36, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\037\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (38, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\039\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (39, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\040\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (40, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\041\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (41, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\042\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (42, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\043\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (43, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\044\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (44, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\045\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (45, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\046\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (46, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\047\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (48, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\049\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (49, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\050\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (50, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\051\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (51, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\052\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (52, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\053\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (54, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\055\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (55, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\056\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (56, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\057\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (57, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\058\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (58, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\059\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (59, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\060\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (60, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\061\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (61, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\062\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (63, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\064\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (64, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\065\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (65, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\066\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (67, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\082\068\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (68, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\075\
\\013\013\013\013\013\013\070\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\069\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (70, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\071\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (71, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\072\013\013\000\013\000\013\000\
\\000"
),
 (72, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\074\013\013\013\
\\013\013\073\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (75, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\076\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (76, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\077\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (77, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\078\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (78, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\079\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (79, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\080\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (80, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\081\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (82, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\083\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (83, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\084\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (84, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\085\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (85, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\086\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (87, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\088\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (88, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\089\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (89, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\090\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (90, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\091\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (91, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\092\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (92, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\093\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (93, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\094\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (94, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\095\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (95, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\096\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (97, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\098\000\000\098\000\000\098\000\000\098\098\000\098\000\098\
\\098\098\098\098\098\098\098\098\098\098\000\000\098\098\098\098\
\\098\098\098\098\098\098\098\098\098\098\098\098\098\098\098\098\
\\098\098\098\098\098\098\098\098\098\098\098\000\000\000\098\098\
\\098\098\098\098\098\098\098\098\098\098\098\098\098\098\098\098\
\\098\098\098\098\098\098\098\098\098\098\098\000\098\000\098\000\
\\000"
),
 (101, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\104\000\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\102\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (102, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\103\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (104, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\105\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (107, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\109\000\000\
\\000\000\000\000\000\000\000\000\000\000\108\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (110, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\018\000\
\\114\114\114\114\114\114\114\114\114\114\000\000\000\000\000\000\
\\000\000\000\000\000\112\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\111\000\
\\000"
),
 (111, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\112\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (112, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\113\113\113\113\113\113\113\113\113\113\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (116, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\013\000\000\013\000\000\013\000\000\013\013\000\013\000\013\
\\013\013\013\013\013\013\013\013\013\013\000\000\013\013\117\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\000\000\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\013\
\\013\013\013\013\013\013\013\013\013\013\013\000\013\000\013\000\
\\000"
),
 (121, 
"\122\122\122\122\122\122\122\122\122\000\000\122\000\122\122\122\
\\122\122\122\122\122\122\122\122\122\122\122\122\122\122\122\122\
\\000\122\122\122\122\122\122\123\122\122\122\122\122\122\122\122\
\\122\122\122\122\122\122\122\122\122\122\122\122\122\122\122\122\
\\122\122\122\122\122\122\122\122\122\122\122\122\122\122\122\122\
\\122\122\122\122\122\122\122\122\122\122\122\122\122\122\122\122\
\\122\122\122\122\122\122\122\122\122\122\122\122\122\122\122\122\
\\122\122\122\122\122\122\122\122\122\122\122\122\122\122\122\122\
\\122"
),
 (125, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\126\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (127, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\162\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\157\000\000\154\000\000\150\000\000\000\146\000\000\000\
\\141\134\000\128\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (128, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\132\000\000\129\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (129, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\130\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (130, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\131\000\000\000\000\000\000\000\000\
\\000"
),
 (132, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\133\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (134, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\135\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (135, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\138\000\000\000\136\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (136, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\137\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (138, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\139\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (139, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\140\000\000\000\000\000\000\
\\000"
),
 (141, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\142\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (142, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\143\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (143, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\144\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (144, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\145\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (146, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\147\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (147, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\148\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (148, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\149\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (150, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\151\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (151, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\152\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (152, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\153\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (154, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\155\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (155, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\156\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (157, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\158\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (158, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\159\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (159, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\160\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (160, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\161\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (164, 
"\000\000\000\000\000\000\000\000\000\165\000\000\165\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\165\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (170, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\171\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (172, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\173\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (174, 
"\175\175\175\175\175\175\175\175\175\175\000\175\175\175\175\175\
\\175\175\175\175\175\175\175\175\175\175\175\175\175\175\175\175\
\\175\175\000\175\175\175\175\175\175\175\175\175\175\175\175\175\
\\175\175\175\175\175\175\175\175\175\175\175\175\175\175\175\175\
\\175\175\175\175\175\175\175\175\175\175\175\175\175\175\175\175\
\\175\175\175\175\175\175\175\175\175\175\175\175\000\175\175\175\
\\175\175\175\175\175\175\175\175\175\175\175\175\175\175\175\175\
\\175\175\175\175\175\175\175\175\175\175\175\175\175\175\175\175\
\\175"
),
 (176, 
"\000\000\000\000\000\000\000\000\000\182\187\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\182\000\186\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\183\183\183\183\183\183\183\183\183\183\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\182\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\181\000\179\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\178\000\
\\000\000\000\000\177\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (179, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\180\180\180\180\180\180\180\180\180\180\180\180\180\180\180\180\
\\180\180\180\180\180\180\180\180\180\180\180\180\180\180\180\180\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (183, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\184\184\184\184\184\184\184\184\184\184\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
 (184, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\185\185\185\185\185\185\185\185\185\185\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000"
),
(0, "")]
fun f x = x 
val s = map f (rev (tl (rev s))) 
exception LexHackingError 
fun look ((j,x)::r, i) = if i = j then x else look(r, i) 
  | look ([], i) = raise LexHackingError
fun g {fin=x, trans=i} = {fin=x, trans=look(s,i)} 
in Vector.fromList(map g 
[{fin = [], trans = 0},
{fin = [(N 1)], trans = 1},
{fin = [(N 1)], trans = 1},
{fin = [], trans = 3},
{fin = [], trans = 3},
{fin = [], trans = 5},
{fin = [], trans = 5},
{fin = [], trans = 7},
{fin = [], trans = 7},
{fin = [], trans = 9},
{fin = [], trans = 9},
{fin = [(N 295)], trans = 0},
{fin = [(N 240),(N 295)], trans = 12},
{fin = [(N 240)], trans = 13},
{fin = [(N 215),(N 240)], trans = 14},
{fin = [(N 240)], trans = 15},
{fin = [(N 240)], trans = 16},
{fin = [(N 233),(N 240)], trans = 16},
{fin = [], trans = 18},
{fin = [(N 233)], trans = 19},
{fin = [], trans = 20},
{fin = [], trans = 21},
{fin = [(N 233)], trans = 21},
{fin = [(N 240),(N 295)], trans = 13},
{fin = [(N 240),(N 295)], trans = 24},
{fin = [(N 240)], trans = 25},
{fin = [(N 240)], trans = 26},
{fin = [(N 133),(N 240)], trans = 13},
{fin = [(N 240),(N 295)], trans = 28},
{fin = [(N 240)], trans = 29},
{fin = [(N 240)], trans = 30},
{fin = [(N 240)], trans = 31},
{fin = [(N 240)], trans = 32},
{fin = [(N 190),(N 240)], trans = 13},
{fin = [(N 240),(N 295)], trans = 34},
{fin = [(N 240)], trans = 35},
{fin = [(N 240)], trans = 36},
{fin = [(N 183),(N 240)], trans = 13},
{fin = [(N 240),(N 295)], trans = 38},
{fin = [(N 240)], trans = 39},
{fin = [(N 240)], trans = 40},
{fin = [(N 240)], trans = 41},
{fin = [(N 240)], trans = 42},
{fin = [(N 240)], trans = 43},
{fin = [(N 240)], trans = 44},
{fin = [(N 240)], trans = 45},
{fin = [(N 240)], trans = 46},
{fin = [(N 211),(N 240)], trans = 13},
{fin = [(N 240),(N 295)], trans = 48},
{fin = [(N 240)], trans = 49},
{fin = [(N 240)], trans = 50},
{fin = [(N 240)], trans = 51},
{fin = [(N 240)], trans = 52},
{fin = [(N 55),(N 240)], trans = 13},
{fin = [(N 240),(N 295)], trans = 54},
{fin = [(N 240)], trans = 55},
{fin = [(N 240)], trans = 56},
{fin = [(N 240)], trans = 57},
{fin = [(N 139),(N 240)], trans = 58},
{fin = [(N 240)], trans = 59},
{fin = [(N 240)], trans = 60},
{fin = [(N 240)], trans = 61},
{fin = [(N 154),(N 240)], trans = 13},
{fin = [(N 240),(N 295)], trans = 63},
{fin = [(N 240)], trans = 64},
{fin = [(N 240)], trans = 65},
{fin = [(N 144),(N 240)], trans = 13},
{fin = [(N 240),(N 295)], trans = 67},
{fin = [(N 240)], trans = 68},
{fin = [(N 178),(N 240)], trans = 13},
{fin = [(N 240)], trans = 70},
{fin = [(N 240)], trans = 71},
{fin = [(N 174),(N 240)], trans = 72},
{fin = [(N 168),(N 240)], trans = 13},
{fin = [(N 161),(N 240)], trans = 13},
{fin = [(N 240)], trans = 75},
{fin = [(N 240)], trans = 76},
{fin = [(N 240)], trans = 77},
{fin = [(N 240)], trans = 78},
{fin = [(N 240)], trans = 79},
{fin = [(N 240)], trans = 80},
{fin = [(N 200),(N 240)], trans = 13},
{fin = [(N 240)], trans = 82},
{fin = [(N 240)], trans = 83},
{fin = [(N 240)], trans = 84},
{fin = [(N 240)], trans = 85},
{fin = [(N 62),(N 240)], trans = 13},
{fin = [(N 240),(N 295)], trans = 87},
{fin = [(N 240)], trans = 88},
{fin = [(N 240)], trans = 89},
{fin = [(N 240)], trans = 90},
{fin = [(N 240)], trans = 91},
{fin = [(N 240)], trans = 92},
{fin = [(N 240)], trans = 93},
{fin = [(N 240)], trans = 94},
{fin = [(N 240)], trans = 95},
{fin = [(N 73),(N 240)], trans = 13},
{fin = [(N 28),(N 246),(N 295)], trans = 97},
{fin = [(N 246)], trans = 97},
{fin = [(N 24),(N 295)], trans = 0},
{fin = [(N 246),(N 295)], trans = 97},
{fin = [(N 37),(N 240),(N 295)], trans = 101},
{fin = [], trans = 102},
{fin = [(N 48)], trans = 0},
{fin = [], trans = 104},
{fin = [(N 44)], trans = 0},
{fin = [(N 33),(N 295)], trans = 0},
{fin = [(N 22),(N 295)], trans = 107},
{fin = [(N 40)], trans = 0},
{fin = [(N 31)], trans = 0},
{fin = [(N 215),(N 295)], trans = 110},
{fin = [], trans = 111},
{fin = [], trans = 112},
{fin = [(N 233)], trans = 112},
{fin = [(N 215)], trans = 110},
{fin = [(N 13),(N 295)], trans = 0},
{fin = [(N 240),(N 295)], trans = 116},
{fin = [(N 20),(N 240)], trans = 13},
{fin = [(N 26),(N 295)], trans = 0},
{fin = [(N 17),(N 295)], trans = 0},
{fin = [(N 15),(N 295)], trans = 0},
{fin = [(N 295)], trans = 121},
{fin = [], trans = 121},
{fin = [(N 250)], trans = 0},
{fin = [(N 35),(N 295)], trans = 0},
{fin = [(N 5),(N 295)], trans = 125},
{fin = [(N 11)], trans = 0},
{fin = [(N 295)], trans = 127},
{fin = [], trans = 128},
{fin = [], trans = 129},
{fin = [], trans = 130},
{fin = [(N 90)], trans = 0},
{fin = [], trans = 132},
{fin = [(N 84)], trans = 0},
{fin = [], trans = 134},
{fin = [], trans = 135},
{fin = [], trans = 136},
{fin = [(N 128)], trans = 0},
{fin = [], trans = 138},
{fin = [], trans = 139},
{fin = [(N 103)], trans = 0},
{fin = [], trans = 141},
{fin = [], trans = 142},
{fin = [], trans = 143},
{fin = [], trans = 144},
{fin = [(N 122)], trans = 0},
{fin = [], trans = 146},
{fin = [], trans = 147},
{fin = [], trans = 148},
{fin = [(N 79)], trans = 0},
{fin = [], trans = 150},
{fin = [], trans = 151},
{fin = [], trans = 152},
{fin = [(N 96)], trans = 0},
{fin = [], trans = 154},
{fin = [], trans = 155},
{fin = [(N 115)], trans = 0},
{fin = [], trans = 157},
{fin = [], trans = 158},
{fin = [], trans = 159},
{fin = [], trans = 160},
{fin = [(N 110)], trans = 0},
{fin = [(N 8)], trans = 0},
{fin = [(N 252),(N 295)], trans = 0},
{fin = [(N 1),(N 295)], trans = 164},
{fin = [(N 1)], trans = 164},
{fin = [(N 3)], trans = 0},
{fin = [(N 299)], trans = 0},
{fin = [(N 297)], trans = 0},
{fin = [(N 307)], trans = 0},
{fin = [(N 307)], trans = 170},
{fin = [(N 305)], trans = 0},
{fin = [(N 307)], trans = 172},
{fin = [(N 302)], trans = 0},
{fin = [(N 255),(N 287)], trans = 174},
{fin = [(N 255)], trans = 174},
{fin = [(N 287)], trans = 176},
{fin = [(N 267)], trans = 0},
{fin = [(N 264)], trans = 0},
{fin = [(N 261)], trans = 179},
{fin = [(N 277)], trans = 0},
{fin = [(N 270)], trans = 0},
{fin = [(N 261)], trans = 0},
{fin = [], trans = 183},
{fin = [], trans = 184},
{fin = [(N 282)], trans = 0},
{fin = [(N 273)], trans = 0},
{fin = [(N 258)], trans = 0},
{fin = [(N 284),(N 287)], trans = 0},
{fin = [(N 287)], trans = 0},
{fin = [(N 293)], trans = 0},
{fin = [(N 289),(N 293)], trans = 0},
{fin = [(N 291),(N 293)], trans = 0}])
end
structure StartStates =
	struct
	datatype yystartstate = STARTSTATE of int

(* start state definitions *)

val COMMENT = STARTSTATE 3;
val FORMAT = STARTSTATE 9;
val INITIAL = STARTSTATE 1;
val NCOMMENT = STARTSTATE 5;
val STRING = STARTSTATE 7;

end
type result = UserDeclarations.lexresult
	exception LexerError (* raised if illegal leaf action tried *)
end

fun makeLexer yyinput =
let	val yygone0=1
	val yyb = ref "\n" 		(* buffer *)
	val yybl = ref 1		(*buffer length *)
	val yybufpos = ref 1		(* location of next character to use *)
	val yygone = ref yygone0	(* position in file of beginning of buffer *)
	val yydone = ref false		(* eof found yet? *)
	val yybegin = ref 1		(*Current 'start state' for lexer *)

	val YYBEGIN = fn (Internal.StartStates.STARTSTATE x) =>
		 yybegin := x

fun lex (yyarg as ((lexarg as (LexerInterface.LA (stream_name, counter))) : LexerInterface.lexarg)) =
let fun continue() : Internal.result = 
  let fun scan (s,AcceptingLeaves : Internal.yyfinstate list list,l,i0) =
	let fun action (i,nil) = raise LexError
	| action (i,nil::l) = action (i-1,l)
	| action (i,(node::acts)::l) =
		case node of
		    Internal.N yyk => 
			(let val yytext = substring(!yyb,i0,i-i0)
			     val yypos = i0+ !yygone
			open UserDeclarations Internal.StartStates
 in (yybufpos := i; case yyk of 

			(* Application actions *)

  1 => (continue())
| 103 => (Tokens.QUERY (yypos, yypos + 6))
| 11 => (commentNesting := (! commentNesting) + 1;
		    YYBEGIN NCOMMENT; continue ())
| 110 => (Tokens.BEGIN (yypos, yypos + 6))
| 115 => (Tokens.END (yypos, yypos + 4))
| 122 => (Tokens.PRINT (yypos, yypos + 6))
| 128 => (Tokens.QUIT (yypos, yypos + 6))
| 13 => (Tokens.DOT (yypos, yypos + 1))
| 133 => (Tokens.TYPE (yypos, yypos + 4))
| 139 => (Tokens.LOCAL (yypos, yypos + 5))
| 144 => (Tokens.KIND (yypos, yypos + 4))
| 15 => (Tokens.LPAREN (yypos, yypos + 1))
| 154 => (Tokens.LOCALKIND (yypos, yypos + 9))
| 161 => (Tokens.INFIXL(yypos,yypos+6))
| 168 => (Tokens.INFIXR(yypos,yypos+6))
| 17 => (Tokens.RPAREN (yypos, yypos + 1))
| 174 => (Tokens.INFIX(yypos,yypos+5))
| 178 => (Tokens.INTTYPE(yypos,yypos+3))
| 183 => (Tokens.REALTYPE (yypos, yypos + 4))
| 190 => (Tokens.STRINGTYPE (yypos, yypos + 6))
| 20 => (Tokens.ARROW (yypos, yypos + 2))
| 200 => (Tokens.INSTREAMTYPE (yypos, yypos + 9))
| 211 => (Tokens.OUTSTREAMTYPE (yypos, yypos + 10))
| 215 => (Tokens.INT (Lib.Convert.atoi yytext, yypos, yypos + size yytext)
     handle Lib.Convert.Convert =>
     (fatal_error
      (ParseError
       (Location
	(make_location counter stream_name (yypos, yypos + (size yytext)),
	 Illegal ("Integer too large.", []))))))
| 22 => (Tokens.COLON (yypos, yypos + 1))
| 233 => (Tokens.REAL (Lib.Convert.atof yytext, yypos, yypos + size yytext)
     handle Lib.Convert.Convert =>
     (fatal_error
      (ParseError
       (Location
	(make_location counter stream_name (yypos, yypos + (size yytext)),
	 Error.Illegal ("Unclosed string.", []))))))
| 24 => (Tokens.BACKSLASH (yypos, yypos + 1))
| 240 => (Tokens.LCID
				    (yytext, yypos,
				     yypos + Lib.String.size yytext))
| 246 => (Tokens.UCID (yytext, yypos,
						 yypos + size yytext))
| 250 => (Tokens.QUID (stripquotes yytext,yypos,
						 yypos + size yytext))
| 252 => (YYBEGIN STRING;
				    str_ref := "";
				    continue ())
| 255 => (str_ref := (!str_ref) ^ yytext;
				    continue ())
| 258 => (next_line counter yypos;
				    YYBEGIN FORMAT;
				    continue ())
| 26 => (Tokens.COMMA (yypos, yypos + 1))
| 261 => (YYBEGIN FORMAT;
				    continue ())
| 264 => (str_ref := (!str_ref) ^ "\n";
				    continue ())
| 267 => (str_ref := (!str_ref) ^ "\t";
				    continue ())
| 270 => (str_ref := (!str_ref) ^ "\\";
				    continue ())
| 273 => (str_ref := (!str_ref) ^ "\"";
				    continue ())
| 277 => (str_ref :=
				    (!str_ref) ^
				    (Lib.String.chr
				     ((Lib.String.ordof (yytext, 3) - 64)));
				    continue ())
| 28 => (Tokens.ANONYMOUS (yypos, yypos + 1))
| 282 => (let
	 val escape_val = Lib.Convert.atoi (Lib.String.substring(yytext, 1, 3))
     in
	 if escape_val > 255 then
	     fatal_error
	     (ParseError
	      (Location
	       (make_location counter stream_name (yypos, yypos + 3),
	        Illegal ("Illegal string escape: %s.",[Error.STRING yytext]))))
	 else
	     (str_ref := (!str_ref) ^ (Lib.String.chr escape_val);
	      continue ())
     end)
| 284 => (YYBEGIN INITIAL;
				    Tokens.STRING (!str_ref, yypos, yypos+1))
| 287 => (fatal_error
     (ParseError
      (Location
       (make_location counter stream_name (yypos, yypos + 1),
        Illegal ("Unclosed string.", [])))))
| 289 => (continue ())
| 291 => (YYBEGIN STRING;
				    continue ())
| 293 => (fatal_error
     (ParseError
      (Location
       (make_location counter stream_name (yypos, yypos + 1),
        Illegal ("Unclosed string.", [])))))
| 295 => (TerminalIO.message
 ((makestring_location (make_location counter stream_name (yypos, yypos + 1)))^
  "Ignoring illegal character " ^ yytext);
 continue())
| 297 => (next_line counter yypos;
				    YYBEGIN INITIAL;
				    continue())
| 299 => (continue())
| 3 => (next_line counter yypos;
				    continue ())
| 302 => (commentNesting := (! commentNesting) + 1;
				    continue())
| 305 => (commentNesting := (! commentNesting) - 1;
				    if (! commentNesting) = 0 then
					YYBEGIN INITIAL
				    else
					();
					continue())
| 307 => (continue())
| 31 => (Tokens.LCID (":-", yypos, yypos + 2))
| 33 => (Tokens.LCID (";", yypos, yypos + 1))
| 35 => (Tokens.LCID ("&", yypos, yypos + 1))
| 37 => (Tokens.LCID ("=", yypos, yypos + 1))
| 40 => (Tokens.LCID ("::", yypos, yypos + 2))
| 44 => (Tokens.LCID ("=:=", yypos, yypos + 3))
| 48 => (Tokens.LCID ("=\\=", yypos, yypos + 3))
| 5 => (YYBEGIN COMMENT; continue ())
| 55 => (Tokens.MODULE (yypos, yypos + 6))
| 62 => (Tokens.IMPORT (yypos, yypos + 6))
| 73 => (Tokens.ACCUMULATE (yypos, yypos + 10))
| 79 => (Tokens.LOAD (yypos, yypos + 5))
| 8 => (YYBEGIN COMMENT; continue ())
| 84 => (Tokens.SET (yypos, yypos + 4))
| 90 => (Tokens.SHOW (yypos, yypos + 5))
| 96 => (Tokens.HELP (yypos, yypos + 5))
| _ => raise Internal.LexerError

		) end )

	val {fin,trans} = Vector.sub(Internal.tab, s)
	val NewAcceptingLeaves = fin::AcceptingLeaves
	in if l = !yybl then
	     if trans = #trans(Vector.sub(Internal.tab,0))
	       then action(l,NewAcceptingLeaves
) else	    let val newchars= if !yydone then "" else yyinput 1024
	    in if (size newchars)=0
		  then (yydone := true;
		        if (l=i0) then UserDeclarations.eof yyarg
		                  else action(l,NewAcceptingLeaves))
		  else (if i0=l then yyb := newchars
		     else yyb := substring(!yyb,i0,l-i0)^newchars;
		     yygone := !yygone+i0;
		     yybl := size (!yyb);
		     scan (s,AcceptingLeaves,l-i0,0))
	    end
	  else let val NewChar = Char.ord(String.sub(!yyb,l))
		val NewState = if NewChar<128 then Char.ord(String.sub(trans,NewChar)) else Char.ord(String.sub(trans,128))
		in if NewState=0 then action(l,NewAcceptingLeaves)
		else scan(NewState,NewAcceptingLeaves,l+1,i0)
	end
	end
(*
	val start= if substring(!yyb,!yybufpos-1,1)="\n"
then !yybegin+1 else !yybegin
*)
	in scan(!yybegin (* start *),nil,!yybufpos,!yybufpos)
    end
in continue end
  in lex
  end
end
