(* lib.sig - basic library						*)

(* Copyright (c) 1991,1994,1995 by Carnegie Mellon University		*)
(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Authors:								*)
(*	Frank Pfenning <fp@cs.cmu.edu>					*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)

signature LIB =
sig
    structure Arith :
	sig
	    exception Overflow;
	    exception Div;
	end;
    structure Convert :
	sig
	    exception Convert;
	    val atoi : string -> int;
	    val atof : string -> real;

	    val itoa : int -> string;
	    val ftoa : real -> string;
	    val btoa : bool -> string;
	end;
    structure Dir :
	sig
	    exception NoSuchFile;
	    val cwd : unit -> string;
	    val mk_path : string * string -> string;
	    val find_file : string list * string -> string;
	    val readable : string -> bool;
	end;
    structure IO :
	sig
	    exception Io of string;
	    type instream;
	    type outstream;
	    val std_in : instream;
	    val std_out : outstream;
	    val std_err : outstream;
	    val open_string : string -> instream;
	    val open_in : string -> instream;
	    val open_out : string -> outstream;
	    val open_append : string -> outstream;
	    val close_in : instream -> unit;
	    val close_out : outstream -> unit;
	    val output : outstream * string -> unit;
	    val flush_out : outstream -> unit;
	    val input : instream * int -> string;
	    val lookahead : instream -> string;
	    val input_line : instream -> string;
	    val end_of_stream : instream -> bool;
	end;
    structure Table : TABLE;
    structure List :
	sig
	    exception Subscript;
	    val lookup: ('a * 'a -> bool) -> 'a -> ('a * 'b) list -> 'b option;
	    val sort : ('a * 'a -> bool) -> 'a list -> 'a list;
	    val nth : 'a list * int -> 'a;
	    val flatten : 'a list list -> 'a list;
	    val reverse : 'a list -> 'a list;
	    val filter : ('a -> 'b option) -> 'a list -> 'b list;
	    val foldl : ('a * 'b -> 'b) -> 'b -> 'a list -> 'b;
	    val foldr : ('a * 'b -> 'b) -> 'b -> 'a list -> 'b;
	    val exists : ('a -> bool) -> 'a list -> bool;
	end;
    structure Misc :
	sig
	    val any : ('a -> bool) -> 'a list -> bool;
	    val uncurry : ('a -> 'b -> 'c) -> ('a * 'b -> 'c);
	    val equal : ''a -> ''a -> bool;
	    val pre_inc : int ref -> int;
	    val pre_dec : int ref -> int;
	    val post_inc : int ref -> int;
	    val post_dec : int ref -> int;
	    val id : 'a -> 'a;
	end;
    structure Signal :
	sig
	    exception Return;
	    val handle_interrupt : (unit -> unit) -> unit
	end;
    structure Int :
	sig
	    val min : int * int -> int;
	    val max : int * int -> int;
	    val rem : int * int -> int;
	    val quot : int * int -> int;
	end;
    structure Real :
	sig
	    val round : real -> int;
	    val ceil : real -> int;
	    val floor : real -> int;
	    val abs : real -> real;
	end;
    structure String :
	sig
	    exception Subscript;
	    exception Chr;
	    val tokenize : string -> string -> string list;
	    val hash_string : string -> int;
	    val upcase : string -> string;
	    val downcase : string -> string;
	    val implode : string list -> string;
	    val explode : string -> string list;
	    val is_whitespace : string -> bool;
	    val size : string -> int;
	    val chr : int -> string;
	    val lessthan : string * string -> bool;
	    val ordof : string * int -> int;
	    val substring : string * int * int -> string;
	end;
    structure Math :
	sig
	    val ln : real -> real;
	    val atan : real -> real;
	    val cos : real -> real;
	    val sin : real -> real;
	    val sqrt : real -> real;
	end;
    structure Env :
	sig
	    val get_value : string -> string option;
	end;
    structure Process :
	sig
	    type status;
	    val success : status;
	    val failure : status;
	end;
    structure Sys :
	sig
	    val date : unit -> string;
	end;

end;
