(* table_hash.fun - interface to NJ/SML lib hash tables.		*)

(* Copyright (c) 1995,1996 by the University of Pennsylvania		*)

(* For information about the distributaion, copying, and modification	*)
(* of this software, please read the file COPYING located in the root	*)
(* directory of this distribnutaion. If you did not receive the file	*)
(* COPYING write to Philip Wickline at the address below.		*)

(* This program is distributed in the hope that it will be useful but	*)
(* WITHOUT ANY WARRANTY; without even the implied warranty of		*)
(* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the file	*)
(* COPYING for more details.						*)

(* For information about the structure of the Terzo lambdaProlog	*)
(* implementation, see the file src/README in this distribution. Please	*)
(* address any questions about this code or the Terzo lambdaProlog	*)
(* implementation to Philip Wickline at <philipw@saul.cis.upenn.edu>.	*)

(* Author:								*)
(*	Philip Wickline <philipw@saul.cis.upenn.edu>			*)


(* This is a very dumb implementation, but at least we don't need to rely
 * on the SML/NJ lib anymore *)

functor TableHash () : TABLE =
    struct
	val baseSize = 128

	datatype ('a, 'b) table =
	    T of {eq : 'a * 'a -> bool,
		  toInt : 'a -> int,
		  tab : ('a * 'b) list array}

	fun mk_table (toInt, eq) =
	    T {toInt = toInt,
	       eq = eq,
	       tab = Array.array (baseSize, nil)};

	fun insert (T {toInt, eq, tab}) (key, item) =
	    let
		val intVal = (toInt key) mod baseSize
		fun find ((pair as (key', _)) :: ls) =
		    if eq (key, key') then
			(key, item) :: ls
		    else
			pair :: (find ls)
		  | find nil = [(key, item)]
	    in
		Array.update (tab, intVal, find (Array.sub (tab, intVal)))
	    end

	fun find (T {toInt, eq, tab}) key =
	    let
		val intVal = (toInt key) mod baseSize
		fun find ((pair as (key', item)) :: ls) =
		    if eq (key, key') then
			SOME item
		    else
			find ls
		  | find nil = NONE
	    in
		find (Array.sub (tab, intVal))
	    end

	fun remove (T {toInt, eq, tab}) key =
	    let
		val intVal = (toInt key) mod baseSize
		fun find ((pair as (key', _)) :: ls) =
		    if eq (key, key') then
			ls
		    else
			pair :: (find ls)
		  | find nil = nil
	    in
		Array.update (tab, intVal, find (Array.sub (tab, intVal)))
	    end

	fun list_items (T {tab, ...}) =
	    let
		fun getItems 0 = Array.sub (tab, 0)
		  | getItems i = (Array.sub (tab, i)) @ (getItems (i - 1))
	    in
		getItems ((Array.length tab) - 1)
	    end;

	fun map f (T {tab, eq, toInt}) =
	    let
		val tab2 = Array.array (Array.length tab, nil)
		fun h ~1 = ()
	      | h i = (Array.update (tab2, i, List.map (fn a as (k, _) => (k, f a)) (Array.sub (tab, i))); h (i - 1))
	    in
		h ((Array.length tab) - 1);
		T {eq = eq, toInt = toInt, tab = tab2}
	    end

(*	val map = Hash.mapi;
	val copy = Hash.copy;
*)
    end; (* functor HashTable *)
